pub enum FileAlignmentInformation {
Byte = 0,
Word = 1,
Long = 3,
Quad = 7,
Octa = 15,
_32Byte = 31,
_64Byte = 63,
_128Byte = 127,
_256Byte = 255,
_512Byte = 511,
}Expand description
Query the buffer alignment required by the underlying device.
Variants
Byte = 0
Specifies that there are no alignment requirements for the device.
Word = 1
Specifies that data must be aligned on a 2-byte boundary.
Long = 3
Specifies that data must be aligned on a 4-byte boundary.
Quad = 7
Specifies that data must be aligned on an 8-byte boundary.
Octa = 15
Specifies that data must be aligned on a 16-byte boundary.
_32Byte = 31
Specifies that data must be aligned on a 32-byte boundary.
_64Byte = 63
Specifies that data must be aligned on a 64-byte boundary.
_128Byte = 127
Specifies that data must be aligned on a 128-byte boundary.
_256Byte = 255
Specifies that data must be aligned on a 256-byte boundary.
_512Byte = 511
Specifies that data must be aligned on a 512-byte boundary.