pub enum NamedPipeConfiguration {
Inbound = 0,
Outbound = 1,
FullDuplex = 2,
}Expand description
Named pipe configuration values.
Variants
Inbound = 0
The flow of data in the pipe goes from client to server only.
Outbound = 1
The flow of data in the pipe goes from server to client only.
FullDuplex = 2
The pipe is bidirectional; both server and client can read from and write to the pipe.