pub struct DirAccessMask { /* private fields */ }Expand description
Directory Access Mask
This is actually taken from the SMB2 protocol, but the bits are the same as the ones used in FSCC for directories.
See MS-SMB2 2.2.13.1.2 - Directory_Access_Mask
This struct was partially generated by the [smb_dtyp::access_mask!][crate::access_mask] macro.
Read more about generic access rights
and standard access rights
Implementations
Sourceimpl DirAccessMask
impl DirAccessMask
Sourceimpl DirAccessMask
impl DirAccessMask
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl DirAccessMask
impl DirAccessMask
Sourcepub fn list_directory(&self) -> <bool as Specifier>::InOut
pub fn list_directory(&self) -> <bool as Specifier>::InOut
Returns the value of list_directory. The right to enumerate the contents of the directory.
Sourcepub fn list_directory_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn list_directory_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of list_directory.
#Errors
If the returned value contains an invalid bit pattern for list_directory. The right to enumerate the contents of the directory.
Sourcepub fn with_list_directory(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_list_directory(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of list_directory set to the given value.
#Panics
If the given value is out of bounds for list_directory. The right to enumerate the contents of the directory.
Sourcepub fn with_list_directory_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_list_directory_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of list_directory set to the given value.
#Errors
If the given value is out of bounds for list_directory. The right to enumerate the contents of the directory.
Sourcepub fn set_list_directory(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_list_directory(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of list_directory to the given value.
#Panics
If the given value is out of bounds for list_directory. The right to enumerate the contents of the directory.
Sourcepub fn set_list_directory_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_list_directory_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of list_directory to the given value.
#Errors
If the given value is out of bounds for list_directory. The right to enumerate the contents of the directory.
Sourcepub fn add_file(&self) -> <bool as Specifier>::InOut
pub fn add_file(&self) -> <bool as Specifier>::InOut
Returns the value of add_file. The right to create a file under the directory.
Sourcepub fn add_file_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn add_file_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of add_file.
#Errors
If the returned value contains an invalid bit pattern for add_file. The right to create a file under the directory.
Sourcepub fn with_add_file(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_add_file(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of add_file set to the given value.
#Panics
If the given value is out of bounds for add_file. The right to create a file under the directory.
Sourcepub fn with_add_file_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_add_file_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of add_file set to the given value.
#Errors
If the given value is out of bounds for add_file. The right to create a file under the directory.
Sourcepub fn set_add_file(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_add_file(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of add_file to the given value.
#Panics
If the given value is out of bounds for add_file. The right to create a file under the directory.
Sourcepub fn set_add_file_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_add_file_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of add_file to the given value.
#Errors
If the given value is out of bounds for add_file. The right to create a file under the directory.
Sourcepub fn add_subdirectory(&self) -> <bool as Specifier>::InOut
pub fn add_subdirectory(&self) -> <bool as Specifier>::InOut
Returns the value of add_subdirectory. The right to add a sub-directory under the directory.
Sourcepub fn add_subdirectory_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn add_subdirectory_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of add_subdirectory.
#Errors
If the returned value contains an invalid bit pattern for add_subdirectory. The right to add a sub-directory under the directory.
Sourcepub fn with_add_subdirectory(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_add_subdirectory(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of add_subdirectory set to the given value.
#Panics
If the given value is out of bounds for add_subdirectory. The right to add a sub-directory under the directory.
Sourcepub fn with_add_subdirectory_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_add_subdirectory_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of add_subdirectory set to the given value.
#Errors
If the given value is out of bounds for add_subdirectory. The right to add a sub-directory under the directory.
Sourcepub fn set_add_subdirectory(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_add_subdirectory(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of add_subdirectory to the given value.
#Panics
If the given value is out of bounds for add_subdirectory. The right to add a sub-directory under the directory.
Sourcepub fn set_add_subdirectory_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_add_subdirectory_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of add_subdirectory to the given value.
#Errors
If the given value is out of bounds for add_subdirectory. The right to add a sub-directory under the directory.
Sourcepub fn read_ea(&self) -> <bool as Specifier>::InOut
pub fn read_ea(&self) -> <bool as Specifier>::InOut
Returns the value of read_ea. The right to read the extended attributes of the directory.
Sourcepub fn read_ea_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn read_ea_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of read_ea.
#Errors
If the returned value contains an invalid bit pattern for read_ea. The right to read the extended attributes of the directory.
Sourcepub fn with_read_ea(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_read_ea(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of read_ea set to the given value.
#Panics
If the given value is out of bounds for read_ea. The right to read the extended attributes of the directory.
Sourcepub fn with_read_ea_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_read_ea_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of read_ea set to the given value.
#Errors
If the given value is out of bounds for read_ea. The right to read the extended attributes of the directory.
Sourcepub fn set_read_ea(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_read_ea(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of read_ea to the given value.
#Panics
If the given value is out of bounds for read_ea. The right to read the extended attributes of the directory.
Sourcepub fn set_read_ea_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_read_ea_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of read_ea to the given value.
#Errors
If the given value is out of bounds for read_ea. The right to read the extended attributes of the directory.
Sourcepub fn write_ea(&self) -> <bool as Specifier>::InOut
pub fn write_ea(&self) -> <bool as Specifier>::InOut
Returns the value of write_ea. The right to write or change the extended attributes of the directory.
Sourcepub fn write_ea_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_ea_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_ea.
#Errors
If the returned value contains an invalid bit pattern for write_ea. The right to write or change the extended attributes of the directory.
Sourcepub fn with_write_ea(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_ea(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_ea set to the given value.
#Panics
If the given value is out of bounds for write_ea. The right to write or change the extended attributes of the directory.
Sourcepub fn with_write_ea_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_ea_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_ea set to the given value.
#Errors
If the given value is out of bounds for write_ea. The right to write or change the extended attributes of the directory.
Sourcepub fn set_write_ea(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_ea(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_ea to the given value.
#Panics
If the given value is out of bounds for write_ea. The right to write or change the extended attributes of the directory.
Sourcepub fn set_write_ea_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_ea_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_ea to the given value.
#Errors
If the given value is out of bounds for write_ea. The right to write or change the extended attributes of the directory.
Sourcepub fn traverse(&self) -> <bool as Specifier>::InOut
pub fn traverse(&self) -> <bool as Specifier>::InOut
Returns the value of traverse. The right to traverse this directory if the server enforces traversal checking.
Sourcepub fn traverse_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn traverse_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of traverse.
#Errors
If the returned value contains an invalid bit pattern for traverse. The right to traverse this directory if the server enforces traversal checking.
Sourcepub fn with_traverse(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_traverse(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of traverse set to the given value.
#Panics
If the given value is out of bounds for traverse. The right to traverse this directory if the server enforces traversal checking.
Sourcepub fn with_traverse_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_traverse_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of traverse set to the given value.
#Errors
If the given value is out of bounds for traverse. The right to traverse this directory if the server enforces traversal checking.
Sourcepub fn set_traverse(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_traverse(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of traverse to the given value.
#Panics
If the given value is out of bounds for traverse. The right to traverse this directory if the server enforces traversal checking.
Sourcepub fn set_traverse_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_traverse_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of traverse to the given value.
#Errors
If the given value is out of bounds for traverse. The right to traverse this directory if the server enforces traversal checking.
Sourcepub fn delete_child(&self) -> <bool as Specifier>::InOut
pub fn delete_child(&self) -> <bool as Specifier>::InOut
Returns the value of delete_child. The right to delete the files and directories within this directory.
Sourcepub fn delete_child_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn delete_child_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of delete_child.
#Errors
If the returned value contains an invalid bit pattern for delete_child. The right to delete the files and directories within this directory.
Sourcepub fn with_delete_child(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_delete_child(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of delete_child set to the given value.
#Panics
If the given value is out of bounds for delete_child. The right to delete the files and directories within this directory.
Sourcepub fn with_delete_child_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_delete_child_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of delete_child set to the given value.
#Errors
If the given value is out of bounds for delete_child. The right to delete the files and directories within this directory.
Sourcepub fn set_delete_child(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_delete_child(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of delete_child to the given value.
#Panics
If the given value is out of bounds for delete_child. The right to delete the files and directories within this directory.
Sourcepub fn set_delete_child_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_delete_child_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of delete_child to the given value.
#Errors
If the given value is out of bounds for delete_child. The right to delete the files and directories within this directory.
Sourcepub fn read_attributes(&self) -> <bool as Specifier>::InOut
pub fn read_attributes(&self) -> <bool as Specifier>::InOut
Returns the value of read_attributes. The right to read the attributes of the directory.
Sourcepub fn read_attributes_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn read_attributes_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of read_attributes.
#Errors
If the returned value contains an invalid bit pattern for read_attributes. The right to read the attributes of the directory.
Sourcepub fn with_read_attributes(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_read_attributes(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of read_attributes set to the given value.
#Panics
If the given value is out of bounds for read_attributes. The right to read the attributes of the directory.
Sourcepub fn with_read_attributes_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_read_attributes_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of read_attributes set to the given value.
#Errors
If the given value is out of bounds for read_attributes. The right to read the attributes of the directory.
Sourcepub fn set_read_attributes(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_read_attributes(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of read_attributes to the given value.
#Panics
If the given value is out of bounds for read_attributes. The right to read the attributes of the directory.
Sourcepub fn set_read_attributes_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_read_attributes_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of read_attributes to the given value.
#Errors
If the given value is out of bounds for read_attributes. The right to read the attributes of the directory.
Sourcepub fn write_attributes(&self) -> <bool as Specifier>::InOut
pub fn write_attributes(&self) -> <bool as Specifier>::InOut
Returns the value of write_attributes. The right to change the attributes of the directory.
Sourcepub fn write_attributes_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_attributes_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_attributes.
#Errors
If the returned value contains an invalid bit pattern for write_attributes. The right to change the attributes of the directory.
Sourcepub fn with_write_attributes(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_attributes(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_attributes set to the given value.
#Panics
If the given value is out of bounds for write_attributes. The right to change the attributes of the directory.
Sourcepub fn with_write_attributes_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_attributes_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_attributes set to the given value.
#Errors
If the given value is out of bounds for write_attributes. The right to change the attributes of the directory.
Sourcepub fn set_write_attributes(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_attributes(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_attributes to the given value.
#Panics
If the given value is out of bounds for write_attributes. The right to change the attributes of the directory.
Sourcepub fn set_write_attributes_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_attributes_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_attributes to the given value.
#Errors
If the given value is out of bounds for write_attributes. The right to change the attributes of the directory.
Sourcepub fn delete(&self) -> <bool as Specifier>::InOut
pub fn delete(&self) -> <bool as Specifier>::InOut
Returns the value of delete. (std) The right to delete the object.
Sourcepub fn delete_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn delete_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of delete.
#Errors
If the returned value contains an invalid bit pattern for delete. (std) The right to delete the object.
Sourcepub fn with_delete(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_delete(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of delete set to the given value.
#Panics
If the given value is out of bounds for delete. (std) The right to delete the object.
Sourcepub fn with_delete_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_delete_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of delete set to the given value.
#Errors
If the given value is out of bounds for delete. (std) The right to delete the object.
Sourcepub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of delete to the given value.
#Panics
If the given value is out of bounds for delete. (std) The right to delete the object.
Sourcepub fn set_delete_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_delete_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of delete to the given value.
#Errors
If the given value is out of bounds for delete. (std) The right to delete the object.
Sourcepub fn read_control(&self) -> <bool as Specifier>::InOut
pub fn read_control(&self) -> <bool as Specifier>::InOut
Returns the value of read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn read_control_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn read_control_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of read_control.
#Errors
If the returned value contains an invalid bit pattern for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn with_read_control(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_read_control(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of read_control set to the given value.
#Panics
If the given value is out of bounds for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn with_read_control_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_read_control_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of read_control set to the given value.
#Errors
If the given value is out of bounds for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn set_read_control(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_read_control(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of read_control to the given value.
#Panics
If the given value is out of bounds for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn set_read_control_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_read_control_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of read_control to the given value.
#Errors
If the given value is out of bounds for read_control. (std) The right to read the information in the object’s security descriptor, not including the information in the system access control list (SACL).
Sourcepub fn write_dacl(&self) -> <bool as Specifier>::InOut
pub fn write_dacl(&self) -> <bool as Specifier>::InOut
Returns the value of write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn write_dacl_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_dacl_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_dacl.
#Errors
If the returned value contains an invalid bit pattern for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn with_write_dacl(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_dacl(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_dacl set to the given value.
#Panics
If the given value is out of bounds for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn with_write_dacl_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_dacl_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_dacl set to the given value.
#Errors
If the given value is out of bounds for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn set_write_dacl(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_dacl(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_dacl to the given value.
#Panics
If the given value is out of bounds for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn set_write_dacl_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_dacl_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_dacl to the given value.
#Errors
If the given value is out of bounds for write_dacl. (std) The right to modify the discretionary access control list (DACL) in the object’s security descriptor.
Sourcepub fn write_owner(&self) -> <bool as Specifier>::InOut
pub fn write_owner(&self) -> <bool as Specifier>::InOut
Returns the value of write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn write_owner_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_owner_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_owner.
#Errors
If the returned value contains an invalid bit pattern for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn with_write_owner(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_owner(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_owner set to the given value.
#Panics
If the given value is out of bounds for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn with_write_owner_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_owner_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_owner set to the given value.
#Errors
If the given value is out of bounds for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn set_write_owner(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_owner(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_owner to the given value.
#Panics
If the given value is out of bounds for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn set_write_owner_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_owner_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_owner to the given value.
#Errors
If the given value is out of bounds for write_owner. (std) The right to change the owner in the security descriptor for the object.
Sourcepub fn synchronize(&self) -> <bool as Specifier>::InOut
pub fn synchronize(&self) -> <bool as Specifier>::InOut
Returns the value of synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn synchronize_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn synchronize_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of synchronize.
#Errors
If the returned value contains an invalid bit pattern for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn with_synchronize(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_synchronize(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of synchronize set to the given value.
#Panics
If the given value is out of bounds for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn with_synchronize_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_synchronize_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of synchronize set to the given value.
#Errors
If the given value is out of bounds for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn set_synchronize(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_synchronize(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of synchronize to the given value.
#Panics
If the given value is out of bounds for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn set_synchronize_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_synchronize_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of synchronize to the given value.
#Errors
If the given value is out of bounds for synchronize. (std) The right to use the object for synchronization. This enables a thread to wait until the object is in the signaled state. Some object types do not support this access right.
Sourcepub fn access_system_security(&self) -> <bool as Specifier>::InOut
pub fn access_system_security(&self) -> <bool as Specifier>::InOut
Returns the value of access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn access_system_security_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn access_system_security_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of access_system_security.
#Errors
If the returned value contains an invalid bit pattern for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn with_access_system_security(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_access_system_security( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of access_system_security set to the given value.
#Panics
If the given value is out of bounds for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn with_access_system_security_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_access_system_security_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of access_system_security set to the given value.
#Errors
If the given value is out of bounds for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn set_access_system_security(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_access_system_security( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of access_system_security to the given value.
#Panics
If the given value is out of bounds for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn set_access_system_security_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_access_system_security_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of access_system_security to the given value.
#Errors
If the given value is out of bounds for access_system_security. The ability to get or set the SACL in an object’s security descriptor.
Read more on MSDN - SACL Access Right
Sourcepub fn maximum_allowed(&self) -> <bool as Specifier>::InOut
pub fn maximum_allowed(&self) -> <bool as Specifier>::InOut
Returns the value of maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn maximum_allowed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn maximum_allowed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of maximum_allowed.
#Errors
If the returned value contains an invalid bit pattern for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn with_maximum_allowed(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_maximum_allowed(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of maximum_allowed set to the given value.
#Panics
If the given value is out of bounds for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn with_maximum_allowed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_maximum_allowed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of maximum_allowed set to the given value.
#Errors
If the given value is out of bounds for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn set_maximum_allowed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_maximum_allowed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of maximum_allowed to the given value.
#Panics
If the given value is out of bounds for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn set_maximum_allowed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_maximum_allowed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of maximum_allowed to the given value.
#Errors
If the given value is out of bounds for maximum_allowed. When requesting access, indicates that the caller wants maximum access rights.
Read more on MSDN - Requesting Access Rights to an Object
Sourcepub fn generic_all(&self) -> <bool as Specifier>::InOut
pub fn generic_all(&self) -> <bool as Specifier>::InOut
Returns the value of generic_all. (generic) All possible access rights
Sourcepub fn generic_all_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_all_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_all.
#Errors
If the returned value contains an invalid bit pattern for generic_all. (generic) All possible access rights
Sourcepub fn with_generic_all(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_all(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_all set to the given value.
#Panics
If the given value is out of bounds for generic_all. (generic) All possible access rights
Sourcepub fn with_generic_all_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_all_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_all set to the given value.
#Errors
If the given value is out of bounds for generic_all. (generic) All possible access rights
Sourcepub fn set_generic_all(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_all(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_all to the given value.
#Panics
If the given value is out of bounds for generic_all. (generic) All possible access rights
Sourcepub fn set_generic_all_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_all_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_all to the given value.
#Errors
If the given value is out of bounds for generic_all. (generic) All possible access rights
Sourcepub fn generic_execute(&self) -> <bool as Specifier>::InOut
pub fn generic_execute(&self) -> <bool as Specifier>::InOut
Returns the value of generic_execute. (generic) Execute access
Sourcepub fn generic_execute_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_execute_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_execute.
#Errors
If the returned value contains an invalid bit pattern for generic_execute. (generic) Execute access
Sourcepub fn with_generic_execute(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_execute(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_execute set to the given value.
#Panics
If the given value is out of bounds for generic_execute. (generic) Execute access
Sourcepub fn with_generic_execute_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_execute_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_execute set to the given value.
#Errors
If the given value is out of bounds for generic_execute. (generic) Execute access
Sourcepub fn set_generic_execute(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_execute(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_execute to the given value.
#Panics
If the given value is out of bounds for generic_execute. (generic) Execute access
Sourcepub fn set_generic_execute_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_execute_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_execute to the given value.
#Errors
If the given value is out of bounds for generic_execute. (generic) Execute access
Sourcepub fn generic_write(&self) -> <bool as Specifier>::InOut
pub fn generic_write(&self) -> <bool as Specifier>::InOut
Returns the value of generic_write. (generic) Write access
Sourcepub fn generic_write_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_write.
#Errors
If the returned value contains an invalid bit pattern for generic_write. (generic) Write access
Sourcepub fn with_generic_write(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_write(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_write set to the given value.
#Panics
If the given value is out of bounds for generic_write. (generic) Write access
Sourcepub fn with_generic_write_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_write set to the given value.
#Errors
If the given value is out of bounds for generic_write. (generic) Write access
Sourcepub fn set_generic_write(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_write(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_write to the given value.
#Panics
If the given value is out of bounds for generic_write. (generic) Write access
Sourcepub fn set_generic_write_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_write to the given value.
#Errors
If the given value is out of bounds for generic_write. (generic) Write access
Sourcepub fn generic_read(&self) -> <bool as Specifier>::InOut
pub fn generic_read(&self) -> <bool as Specifier>::InOut
Returns the value of generic_read. (generic) Read access
Sourcepub fn generic_read_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_read_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_read.
#Errors
If the returned value contains an invalid bit pattern for generic_read. (generic) Read access
Sourcepub fn with_generic_read(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_read(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_read set to the given value.
#Panics
If the given value is out of bounds for generic_read. (generic) Read access
Sourcepub fn with_generic_read_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_read_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_read set to the given value.
#Errors
If the given value is out of bounds for generic_read. (generic) Read access
Sourcepub fn set_generic_read(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_read(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_read to the given value.
#Panics
If the given value is out of bounds for generic_read. (generic) Read access
Sourcepub fn set_generic_read_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_read_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_read to the given value.
#Errors
If the given value is out of bounds for generic_read. (generic) Read access