EaFlags

Struct EaFlags 

pub struct EaFlags { /* private fields */ }
Extended Attribute (EA) Flags

See FileFullEaInformationInner

Implementations

Source

impl EaFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl EaFlags

pub const fn into_bytes(self) -> [u8; 1]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 1]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl EaFlags

pub fn file_need_ea(&self) -> <bool as Specifier>::InOut

Returns the value of file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.

pub fn file_need_ea_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of file_need_ea.

#Errors

If the returned value contains an invalid bit pattern for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.

pub fn with_file_need_ea(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of file_need_ea set to the given value.

#Panics

If the given value is out of bounds for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.

pub fn with_file_need_ea_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of file_need_ea set to the given value.

#Errors

If the given value is out of bounds for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.

pub fn set_file_need_ea(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of file_need_ea to the given value.

#Panics

If the given value is out of bounds for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.

pub fn set_file_need_ea_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of file_need_ea to the given value.

#Errors

If the given value is out of bounds for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.