pub struct FileAccessInformation {
pub access_flags: FileAccessMask,
}Expand description
Query the access rights of a file that were granted when the file was opened.
Fields
access_flags: FileAccessMaskContains values that specify the access rights that were granted when the file was opened.