FileAllocationInformation

Struct FileAllocationInformation 

pub struct FileAllocationInformation {
    pub allocation_size: u64,
}
Set the allocation size for a file.

The file system is passed a 64-bit signed integer containing the file allocation size, in bytes. The file system rounds the requested allocation size up to an integer multiple of the cluster size for nonresident files, or an implementation-defined multiple for resident files. All unused allocation (beyond EOF) is freed on the last handle close.

MS-FSCC 2.4.4

Fields

allocation_size: u64

The new allocation size in bytes. Usually a multiple of the sector or cluster size of the underlying physical device.