pub struct FileAttributeTagInformation {
pub file_attributes: FileAttributes,
pub reparse_tag: ReparseTag,
}Expand description
Query file attribute and reparse tag information for a file.
Fields
file_attributes: FileAttributesFile attributes as a bitmask of flags.
reparse_tag: ReparseTagThe reparse point tag value. If the file is not a reparse point, this value is undefined and should not be used.