pub struct FileCompressionInformation {
pub compressed_file_size: u64,
pub compression_format: FileCompressionFormat,
pub compression_unit: u8,
pub chunk_shift: u8,
pub cluster_shift: u8,
}Expand description
Query compression information for a file.
Fields
compressed_file_size: u64The size of the compressed file in bytes.
compression_format: FileCompressionFormatThe compression format used for the file.
compression_unit: u8The compression unit size in bytes as a power of 2.
chunk_shift: u8The compression chunk size in bytes as a power of 2.
cluster_shift: u8The cluster size in bytes as a power of 2.