pub struct FileDirectoryInformation {
pub file_index: u32,
pub creation_time: FileTime,
pub last_access_time: FileTime,
pub last_write_time: FileTime,
pub change_time: FileTime,
pub end_of_file: u64,
pub allocation_size: u64,
pub file_attributes: FileAttributes,
pub file_name: SizedWideString,
}Expand description
Query detailed information for the files in a directory.
This should be wrapped in ChainedItemList<T> to represent a list of these structures.
Fields
file_index: u32The byte offset of the file within the parent directory. This member is undefined for file systems, such as NTFS, in which the position of a file within the parent directory is not fixed and can be changed at any time to maintain sort order.
creation_time: FileTimeThe time when the file was created.
last_access_time: FileTimeThe time when the file was last accessed.
last_write_time: FileTimeThe time when data was last written to the file.
change_time: FileTimeThe time when the file was last changed.
end_of_file: u64The absolute new end-of-file position as a byte offset from the start of the file.
allocation_size: u64The number of bytes allocated for the file.
file_attributes: FileAttributesThe file attributes.
file_name: SizedWideStringThe name of the file.