pub struct FileFsFullSizeInformation {
pub total_allocation_units: u64,
pub caller_available_allocation_units: u64,
pub actual_available_allocation_units: u64,
pub sectors_per_allocation_unit: u32,
pub bytes_per_sector: u32,
}Expand description
Query sector size information for a file system volume.
Fields
total_allocation_units: u64caller_available_allocation_units: u64actual_available_allocation_units: u64sectors_per_allocation_unit: u32bytes_per_sector: u32Trait Implementations
Sourceimpl BinRead for FileFsFullSizeInformation
impl BinRead for FileFsFullSizeInformation
Sourcefn read_options<R: Read + Seek>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<Self>
fn read_options<R: Read + Seek>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<Self>
Sourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for FileFsFullSizeInformation
impl BinWrite for FileFsFullSizeInformation
Sourcefn write_options<W: Write + Seek>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: Self::Args<'_>,
) -> BinResult<()>
fn write_options<W: Write + Seek>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: Self::Args<'_>, ) -> BinResult<()>
Sourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Debug for FileFsFullSizeInformation
impl Debug for FileFsFullSizeInformation
Sourceimpl From<FileFsFullSizeInformation> for QueryFileSystemInfo
impl From<FileFsFullSizeInformation> for QueryFileSystemInfo
Sourcefn from(value: FileFsFullSizeInformation) -> QueryFileSystemInfo
fn from(value: FileFsFullSizeInformation) -> QueryFileSystemInfo
Converts to this type from the input type.
Sourceimpl QueryFileSystemInfoValue for FileFsFullSizeInformation
impl QueryFileSystemInfoValue for FileFsFullSizeInformation
const CLASS_ID: QueryFileSystemInfoClass = QueryFileSystemInfoClass::FsFullSizeInformation
Sourceimpl TryFrom<QueryFileSystemInfo> for FileFsFullSizeInformation
impl TryFrom<QueryFileSystemInfo> for FileFsFullSizeInformation
Sourcetype Error = SmbFsccError
type Error = SmbFsccError
The type returned in the event of a conversion error.
impl Eq for FileFsFullSizeInformation
impl StructuralPartialEq for FileFsFullSizeInformation