FileFsSectorSizeInformation

Struct FileFsSectorSizeInformation 

pub struct FileFsSectorSizeInformation {
    pub logical_bytes_per_sector: u32,
    pub physical_bytes_per_sector: u32,
    pub physical_bytes_per_sector_for_performance: u32,
    pub effective_physical_bytes_per_sector_for_atomicity: u32,
    pub flags: SectorSizeInfoFlags,
    pub byte_offset_for_sector_alignment: u32,
    pub byte_offset_for_partition_alignment: u32,
}
Query for the extended sector size and alignment information for a volume.

The message contains a FILE_FS_SECTOR_SIZE_INFORMATION data element.

MS-FSCC 2.5.7

Fields

logical_bytes_per_sector: u32

The number of bytes in a logical sector for the device backing the volume. This field is the unit of logical addressing for the device and is not the unit of atomic write. Applications SHOULD NOT utilize this value for operations requiring physical sector alignment.

physical_bytes_per_sector: u32

The number of bytes in a physical sector for the device backing the volume. Note that this is the reported physical sector size of the device and is the unit of atomic write. Applications SHOULD utilize this value for operations requiring sector alignment.

physical_bytes_per_sector_for_performance: u32

The number of bytes in a physical sector for the device backing the volume. This is the reported physical sector size of the device and is the unit of performance. Applications SHOULD utilize this value for operations requiring sector alignment.

effective_physical_bytes_per_sector_for_atomicity: u32

The unit, in bytes, that the file system on the volume will use for internal operations that require alignment and atomicity.

flags: SectorSizeInfoFlags

Flags for this operation.

byte_offset_for_sector_alignment: u32

The logical sector offset within the first physical sector where the first logical sector is placed, in bytes. If this value is set to SSINFO_OFFSET_UNKNOWN (0XFFFFFFFF), there was insufficient information to compute this field.

byte_offset_for_partition_alignment: u32

The byte offset from the first physical sector where the first partition is placed. If this value is set to SSINFO_OFFSET_UNKNOWN (0XFFFFFFFF), there was either insufficient information or an error was encountered in computing this field.