pub struct FileId64ExtdBothDirectoryInformation {Show 15 fields
pub file_index: u32,
pub creation_time: FileTime,
pub last_access_time: FileTime,
pub last_write_time: FileTime,
pub change_time: FileTime,
pub end_of_file: u64,
pub allocation_size: u64,
pub file_attributes: FileAttributes,
pub ea_size: Option<u32>,
pub reparse_tag: Option<ReparseTag>,
pub reparse_point_tag: u32,
pub file_id: u64,
pub short_name_length: u8,
pub short_name: FixedWideString<12>,
pub file_name: SizedWideString,
}Expand description
Query detailed information for the files in a directory.
Note: This should be wrapped in
ChainedItemList<T>to represent a list of these structures.
Fields
file_index: u32The byte offset of the file within the parent directory. This member is undefined for file systems, such as NTFS, in which the position of a file within the parent directory is not fixed and can be changed at any time to maintain sort order.
creation_time: FileTimeThe time when the file was created.
last_access_time: FileTimeThe time when the file was last accessed.
last_write_time: FileTimeThe time when data was last written to the file.
change_time: FileTimeThe time when the file was last changed.
end_of_file: u64The absolute new end-of-file position as a byte offset from the start of the file.
allocation_size: u64The number of bytes allocated for the file.
file_attributes: FileAttributesThe file attributes.
ea_size: Option<u32>The size of the extended attributes for the file.
reparse_tag: Option<ReparseTag>The reparse point tag. If the file is not a reparse point, this value is 0.
reparse_point_tag: u32The reparse point tag. If the file is not a reparse point, this value is 0.
file_id: u64The file ID.
short_name_length: u8The length, in bytes, of the short name string.
short_name: FixedWideString<12>The short (8.3) name of the file.
file_name: SizedWideStringThe name of the file.