FileIdBothDirectoryInformation

Struct FileIdBothDirectoryInformation 

pub struct FileIdBothDirectoryInformation {
Show 14 fields pub file_index: u32, pub creation_time: FileTime, pub last_access_time: FileTime, pub last_write_time: FileTime, pub change_time: FileTime, pub end_of_file: u64, pub allocation_size: u64, pub file_attributes: FileAttributes, pub ea_size: Option<u32>, pub reparse_tag: Option<ReparseTag>, pub short_name_length: u8, pub short_name: FixedWideString<12>, pub file_id: u64, pub file_name: SizedWideString,
}
Query detailed information for the files in a directory.

MS-FSCC 2.4.22

Note: This should be wrapped in ChainedItemList<T> to represent a list of these structures.

Fields

file_index: u32

The byte offset of the file within the parent directory. This member is undefined for file systems, such as NTFS, in which the position of a file within the parent directory is not fixed and can be changed at any time to maintain sort order.

creation_time: FileTime

The time when the file was created.

last_access_time: FileTime

The time when the file was last accessed.

last_write_time: FileTime

The time when data was last written to the file.

change_time: FileTime

The time when the file was last changed.

end_of_file: u64

The absolute new end-of-file position as a byte offset from the start of the file.

allocation_size: u64

The number of bytes allocated for the file.

file_attributes: FileAttributes

The file attributes.

ea_size: Option<u32>

The size of the extended attributes for the file.

reparse_tag: Option<ReparseTag>

The reparse point tag. If the file is not a reparse point, this value is 0.

short_name_length: u8

The length, in bytes, of the short name string.

short_name: FixedWideString<12>

The short (8.3) name of the file.

file_id: u64

The file ID.

file_name: SizedWideString

The name of the file.