pub struct FileIdInformation {
pub volume_serial_number: u64,
pub file_id: u128,
}Expand description
Query the file system’s 8-byte file reference number for a file.
Fields
volume_serial_number: u64The serial number of the volume containing the file.
file_id: u128A 128-bit file identifier that uniquely identifies a file within the file system.