pub struct FileLinkInformation {
pub replace_if_exists: Boolean,
pub file_name: SizedWideString,
}Expand description
Create a hard link to an existing file via the SMB Version 2 Protocol, as specified in [MS-SMB2].
WARNING: This operation is currently unstable and untested, and may lead to data loss or corruption if used improperly!
MS-FSCC 2.4.8.2 - FileLinkInformation for SMB2 protocol
Fields
replace_if_exists: BooleanSet to TRUE to indicate that if a file with the given name already exists, it should be replaced with the given file. Set to FALSE if the link operation should fail if a file with the given name already exists.
file_name: SizedWideStringThe name to be assigned to the newly created link.