pub struct FileModeInformation { /* private fields */ }Expand description
Query or Set file mode information.
Implementations
Sourceimpl FileModeInformation
impl FileModeInformation
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl FileModeInformation
impl FileModeInformation
Sourcepub fn write_through(&self) -> <bool as Specifier>::InOut
pub fn write_through(&self) -> <bool as Specifier>::InOut
Returns the value of write_through. When set, system caching is not performed on the file.
Sourcepub fn write_through_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_through_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_through.
#Errors
If the returned value contains an invalid bit pattern for write_through. When set, system caching is not performed on the file.
Sourcepub fn with_write_through(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_through(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_through set to the given value.
#Panics
If the given value is out of bounds for write_through. When set, system caching is not performed on the file.
Sourcepub fn with_write_through_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_through_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_through set to the given value.
#Errors
If the given value is out of bounds for write_through. When set, system caching is not performed on the file.
Sourcepub fn set_write_through(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_through(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_through to the given value.
#Panics
If the given value is out of bounds for write_through. When set, system caching is not performed on the file.
Sourcepub fn set_write_through_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_through_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_through to the given value.
#Errors
If the given value is out of bounds for write_through. When set, system caching is not performed on the file.
Sourcepub fn sequential_access(&self) -> <bool as Specifier>::InOut
pub fn sequential_access(&self) -> <bool as Specifier>::InOut
Returns the value of sequential_access. When set, all access to the file is sequential.
Sourcepub fn sequential_access_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sequential_access_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sequential_access.
#Errors
If the returned value contains an invalid bit pattern for sequential_access. When set, all access to the file is sequential.
Sourcepub fn with_sequential_access(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_sequential_access(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of sequential_access set to the given value.
#Panics
If the given value is out of bounds for sequential_access. When set, all access to the file is sequential.
Sourcepub fn with_sequential_access_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sequential_access_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sequential_access set to the given value.
#Errors
If the given value is out of bounds for sequential_access. When set, all access to the file is sequential.
Sourcepub fn set_sequential_access(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sequential_access(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sequential_access to the given value.
#Panics
If the given value is out of bounds for sequential_access. When set, all access to the file is sequential.
Sourcepub fn set_sequential_access_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sequential_access_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sequential_access to the given value.
#Errors
If the given value is out of bounds for sequential_access. When set, all access to the file is sequential.
Sourcepub fn no_intermediate_buffering(&self) -> <bool as Specifier>::InOut
pub fn no_intermediate_buffering(&self) -> <bool as Specifier>::InOut
Returns the value of no_intermediate_buffering. When set, the file cannot be cached or buffered in a driver’s internal buffers.
Sourcepub fn no_intermediate_buffering_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn no_intermediate_buffering_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of no_intermediate_buffering.
#Errors
If the returned value contains an invalid bit pattern for no_intermediate_buffering. When set, the file cannot be cached or buffered in a driver’s internal buffers.
Sourcepub fn with_no_intermediate_buffering(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_no_intermediate_buffering( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of no_intermediate_buffering set to the given value.
#Panics
If the given value is out of bounds for no_intermediate_buffering. When set, the file cannot be cached or buffered in a driver’s internal buffers.
Sourcepub fn with_no_intermediate_buffering_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_no_intermediate_buffering_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of no_intermediate_buffering set to the given value.
#Errors
If the given value is out of bounds for no_intermediate_buffering. When set, the file cannot be cached or buffered in a driver’s internal buffers.
Sourcepub fn set_no_intermediate_buffering(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_no_intermediate_buffering( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of no_intermediate_buffering to the given value.
#Panics
If the given value is out of bounds for no_intermediate_buffering. When set, the file cannot be cached or buffered in a driver’s internal buffers.
Sourcepub fn set_no_intermediate_buffering_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_no_intermediate_buffering_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of no_intermediate_buffering to the given value.
#Errors
If the given value is out of bounds for no_intermediate_buffering. When set, the file cannot be cached or buffered in a driver’s internal buffers.
Sourcepub fn synchronous_io_alert(&self) -> <bool as Specifier>::InOut
pub fn synchronous_io_alert(&self) -> <bool as Specifier>::InOut
Returns the value of synchronous_io_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are alertable.
Sourcepub fn synchronous_io_alert_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn synchronous_io_alert_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of synchronous_io_alert.
#Errors
If the returned value contains an invalid bit pattern for synchronous_io_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are alertable.
Sourcepub fn with_synchronous_io_alert(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_synchronous_io_alert( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of synchronous_io_alert set to the given value.
#Panics
If the given value is out of bounds for synchronous_io_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are alertable.
Sourcepub fn with_synchronous_io_alert_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_synchronous_io_alert_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of synchronous_io_alert set to the given value.
#Errors
If the given value is out of bounds for synchronous_io_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are alertable.
Sourcepub fn set_synchronous_io_alert(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_synchronous_io_alert(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of synchronous_io_alert to the given value.
#Panics
If the given value is out of bounds for synchronous_io_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are alertable.
Sourcepub fn set_synchronous_io_alert_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_synchronous_io_alert_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of synchronous_io_alert to the given value.
#Errors
If the given value is out of bounds for synchronous_io_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are alertable.
Sourcepub fn synchronous_io_non_alert(&self) -> <bool as Specifier>::InOut
pub fn synchronous_io_non_alert(&self) -> <bool as Specifier>::InOut
Returns the value of synchronous_io_non_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are not alertable.
Sourcepub fn synchronous_io_non_alert_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn synchronous_io_non_alert_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of synchronous_io_non_alert.
#Errors
If the returned value contains an invalid bit pattern for synchronous_io_non_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are not alertable.
Sourcepub fn with_synchronous_io_non_alert(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_synchronous_io_non_alert( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of synchronous_io_non_alert set to the given value.
#Panics
If the given value is out of bounds for synchronous_io_non_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are not alertable.
Sourcepub fn with_synchronous_io_non_alert_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_synchronous_io_non_alert_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of synchronous_io_non_alert set to the given value.
#Errors
If the given value is out of bounds for synchronous_io_non_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are not alertable.
Sourcepub fn set_synchronous_io_non_alert(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_synchronous_io_non_alert( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of synchronous_io_non_alert to the given value.
#Panics
If the given value is out of bounds for synchronous_io_non_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are not alertable.
Sourcepub fn set_synchronous_io_non_alert_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_synchronous_io_non_alert_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of synchronous_io_non_alert to the given value.
#Errors
If the given value is out of bounds for synchronous_io_non_alert. When set, all operations on the file are performed synchronously. Waits in the system to synchronize I/O queuing and completion are not alertable.
Sourcepub fn delete_on_close(&self) -> <bool as Specifier>::InOut
pub fn delete_on_close(&self) -> <bool as Specifier>::InOut
Returns the value of delete_on_close. When set, the file will be deleted when the last handle to the file is closed.
Sourcepub fn delete_on_close_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn delete_on_close_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of delete_on_close.
#Errors
If the returned value contains an invalid bit pattern for delete_on_close. When set, the file will be deleted when the last handle to the file is closed.
Sourcepub fn with_delete_on_close(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_delete_on_close(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of delete_on_close set to the given value.
#Panics
If the given value is out of bounds for delete_on_close. When set, the file will be deleted when the last handle to the file is closed.
Sourcepub fn with_delete_on_close_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_delete_on_close_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of delete_on_close set to the given value.
#Errors
If the given value is out of bounds for delete_on_close. When set, the file will be deleted when the last handle to the file is closed.
Sourcepub fn set_delete_on_close(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_delete_on_close(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of delete_on_close to the given value.
#Panics
If the given value is out of bounds for delete_on_close. When set, the file will be deleted when the last handle to the file is closed.
Sourcepub fn set_delete_on_close_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_delete_on_close_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of delete_on_close to the given value.
#Errors
If the given value is out of bounds for delete_on_close. When set, the file will be deleted when the last handle to the file is closed.