pub struct FileNamesInformation {
pub file_index: u32,
pub file_name: SizedWideString,
}Expand description
Query the names of the files in a directory.
This should be wrapped in ChainedItemList<T> to represent a list of these structures.
Fields
file_index: u32The byte offset of the file within the parent directory. This member is undefined for file systems, such as NTFS, in which the position of a file within the parent directory is not fixed and can be changed at any time to maintain sort order.
file_name: SizedWideStringThe name of the file.