pub struct FileNetworkOpenInformation {
pub creation_time: FileTime,
pub last_access_time: FileTime,
pub last_write_time: FileTime,
pub change_time: FileTime,
pub allocation_size: u64,
pub end_of_file: u64,
pub file_attributes: FileAttributes,
}Expand description
Query network file open information for a file.
Fields
creation_time: FileTimeThe time when the file was created.
last_access_time: FileTimeThe time when the file was last accessed.
last_write_time: FileTimeThe time when data was last written to the file.
change_time: FileTimeThe time when the file was last changed.
allocation_size: u64The number of bytes that are allocated for the file.
end_of_file: u64The end of file location as a byte offset from the start of the file.
file_attributes: FileAttributesThe file attributes.