pub struct FilePipeLocalInformation {
pub named_pipe_type: NamedPipeType,
pub named_pipe_configuration: NamedPipeConfiguration,
pub maximum_instances: u32,
pub current_instances: u32,
pub inbound_quota: u32,
pub read_data_available: u32,
pub outbound_quota: u32,
pub write_quota_available: u32,
pub named_pipe_state: NamedPipeState,
pub named_pipe_end: NamedPipeEnd,
}Expand description
Query information associated with a named pipe that is not specific to one end of the pipe or another.
Fields
named_pipe_type: NamedPipeTypeThe type of named pipe.
named_pipe_configuration: NamedPipeConfigurationThe named pipe configuration.
maximum_instances: u32The maximum number of instances that can be created for this pipe.
current_instances: u32The number of current named pipe instances.
inbound_quota: u32The inbound quota in bytes.
read_data_available: u32Bytes of data available to be read from the named pipe.
outbound_quota: u32The outbound quota in bytes.
write_quota_available: u32The write quota in bytes.
named_pipe_state: NamedPipeStateThe named pipe state.
named_pipe_end: NamedPipeEndSpecifies whether the named pipe handle is for the client or server end of a named pipe.