FilePipeRemoteInformation

Struct FilePipeRemoteInformation 

pub struct FilePipeRemoteInformation {
    pub collect_data_time: FileTime,
    pub maximum_collection_count: u32,
}
Query information that is associated with the remote end of a named pipe.

MS-FSCC 2.4.39

Fields

collect_data_time: FileTime

The time at which the data is collected.

maximum_collection_count: u32

The maximum size, in bytes, of data that will be collected before transmission to the remote end of the named pipe.