pub struct FilePositionInformation {
pub current_byte_offset: u64,
}Expand description
Query or Set the current byte offset of the file pointer.
Fields
current_byte_offset: u64The byte offset of the file pointer from the beginning of the file.