FileQuotaInformation

Struct FileQuotaInformation 

pub struct FileQuotaInformation {
    pub change_time: FileTime,
    pub quota_used: u64,
    pub quota_threshold: u64,
    pub quota_limit: u64,
    pub sid: SID,
}
Query or to set file quota information for a volume.

For queries, an optional buffer of FILE_GET_QUOTA_INFORMATION (section 2.4.41.1) data elements is provided by the client to specify the SIDs for which quota information is requested. If the FILE_GET_QUOTA_INFORMATION buffer is not specified, information for all quotas is returned. A buffer of FILE_QUOTA_INFORMATION data elements is returned by the server. For sets, FILE_QUOTA_INFORMATION data elements are populated and sent by the client, as specified in [MS-SMB] section 2.2.7.6.1 and [MS-SMB2] section 3.2.4.15.<145>

MS-FSCC 2.4.41

Note: This structure is partial: it does not contain the NextEntryOffset field, as it is intended to be used in a chained list, see ChainedItemList<T>.

Fields

change_time: FileTimequota_used: u64quota_threshold: u64quota_limit: u64sid: SID

Implementations

Source

impl FileQuotaInformation

pub const MIN_SIZE: usize = 44usize

Minimum size of this structure in bytes.