pub struct FileRenameInformation {
pub replace_if_exists: Boolean,
pub root_directory: u64,
pub file_name: SizedWideString,
}Expand description
Rename a file within the SMB2 protocol.
MS-FSCC 2.4.42.2 - FileRenameInformation for SMB2 protocol
Fields
replace_if_exists: BooleanSet to TRUE to indicate that if a file with the given name already exists, it should be replaced with the given file. Set to FALSE if the rename operation should fail if a file with the given name already exists.
root_directory: u64A file handle for the root directory. For network operations, this value must be zero.
file_name: SizedWideStringThe new name for the file, including the full path.