pub struct FileStandardInformation {
pub allocation_size: u64,
pub end_of_file: u64,
pub number_of_links: u32,
pub delete_pending: Boolean,
pub directory: Boolean,
}Expand description
Query standard information for a file.
Fields
allocation_size: u64The number of bytes that are allocated for the file.
end_of_file: u64The end of file location as a byte offset from the start of the file.
number_of_links: u32The number of non-deleted hard links to this file.
delete_pending: BooleanSet to TRUE if the file has been marked for deletion.
directory: BooleanSet to TRUE if the file is a directory.