FileSystemControlFlags

Struct FileSystemControlFlags 

pub struct FileSystemControlFlags { /* private fields */ }
File system control flags.

Used in FileFsControlInformation

Implementations

Source

impl FileSystemControlFlags

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl FileSystemControlFlags

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl FileSystemControlFlags

pub fn quota_track(&self) -> <bool as Specifier>::InOut

Returns the value of quota_track. Quotas are tracked on the volume, but they are not enforced. Tracked quotas enable reporting on the file system space used by system users. If both this flag and FILE_VC_QUOTA_ENFORCE are specified, FILE_VC_QUOTA_ENFORCE is ignored.

Note: This flag takes precedence over FILE_VC_QUOTA_ENFORCE. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn quota_track_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of quota_track.

#Errors

If the returned value contains an invalid bit pattern for quota_track. Quotas are tracked on the volume, but they are not enforced. Tracked quotas enable reporting on the file system space used by system users. If both this flag and FILE_VC_QUOTA_ENFORCE are specified, FILE_VC_QUOTA_ENFORCE is ignored.

Note: This flag takes precedence over FILE_VC_QUOTA_ENFORCE. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn with_quota_track(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of quota_track set to the given value.

#Panics

If the given value is out of bounds for quota_track. Quotas are tracked on the volume, but they are not enforced. Tracked quotas enable reporting on the file system space used by system users. If both this flag and FILE_VC_QUOTA_ENFORCE are specified, FILE_VC_QUOTA_ENFORCE is ignored.

Note: This flag takes precedence over FILE_VC_QUOTA_ENFORCE. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn with_quota_track_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of quota_track set to the given value.

#Errors

If the given value is out of bounds for quota_track. Quotas are tracked on the volume, but they are not enforced. Tracked quotas enable reporting on the file system space used by system users. If both this flag and FILE_VC_QUOTA_ENFORCE are specified, FILE_VC_QUOTA_ENFORCE is ignored.

Note: This flag takes precedence over FILE_VC_QUOTA_ENFORCE. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn set_quota_track(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of quota_track to the given value.

#Panics

If the given value is out of bounds for quota_track. Quotas are tracked on the volume, but they are not enforced. Tracked quotas enable reporting on the file system space used by system users. If both this flag and FILE_VC_QUOTA_ENFORCE are specified, FILE_VC_QUOTA_ENFORCE is ignored.

Note: This flag takes precedence over FILE_VC_QUOTA_ENFORCE. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn set_quota_track_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of quota_track to the given value.

#Errors

If the given value is out of bounds for quota_track. Quotas are tracked on the volume, but they are not enforced. Tracked quotas enable reporting on the file system space used by system users. If both this flag and FILE_VC_QUOTA_ENFORCE are specified, FILE_VC_QUOTA_ENFORCE is ignored.

Note: This flag takes precedence over FILE_VC_QUOTA_ENFORCE. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn quota_enforce(&self) -> <bool as Specifier>::InOut

Returns the value of quota_enforce. Quotas are tracked and enforced on the volume.

Note: FILE_VC_QUOTA_TRACK takes precedence over this flag. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn quota_enforce_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of quota_enforce.

#Errors

If the returned value contains an invalid bit pattern for quota_enforce. Quotas are tracked and enforced on the volume.

Note: FILE_VC_QUOTA_TRACK takes precedence over this flag. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn with_quota_enforce(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of quota_enforce set to the given value.

#Panics

If the given value is out of bounds for quota_enforce. Quotas are tracked and enforced on the volume.

Note: FILE_VC_QUOTA_TRACK takes precedence over this flag. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn with_quota_enforce_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of quota_enforce set to the given value.

#Errors

If the given value is out of bounds for quota_enforce. Quotas are tracked and enforced on the volume.

Note: FILE_VC_QUOTA_TRACK takes precedence over this flag. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn set_quota_enforce(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of quota_enforce to the given value.

#Panics

If the given value is out of bounds for quota_enforce. Quotas are tracked and enforced on the volume.

Note: FILE_VC_QUOTA_TRACK takes precedence over this flag. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn set_quota_enforce_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of quota_enforce to the given value.

#Errors

If the given value is out of bounds for quota_enforce. Quotas are tracked and enforced on the volume.

Note: FILE_VC_QUOTA_TRACK takes precedence over this flag. In other words, if both FILE_VC_QUOTA_TRACK and FILE_VC_QUOTA_ENFORCE are set, the FILE_VC_QUOTA_ENFORCE flag is ignored. This flag will be ignored if a client attempts to set it.

pub fn content_indexing_disabled(&self) -> <bool as Specifier>::InOut

Returns the value of content_indexing_disabled. Content indexing is disabled.

pub fn content_indexing_disabled_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of content_indexing_disabled.

#Errors

If the returned value contains an invalid bit pattern for content_indexing_disabled. Content indexing is disabled.

pub fn with_content_indexing_disabled( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of content_indexing_disabled set to the given value.

#Panics

If the given value is out of bounds for content_indexing_disabled. Content indexing is disabled.

pub fn with_content_indexing_disabled_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of content_indexing_disabled set to the given value.

#Errors

If the given value is out of bounds for content_indexing_disabled. Content indexing is disabled.

pub fn set_content_indexing_disabled( &mut self, new_val: <bool as Specifier>::InOut, )

Sets the value of content_indexing_disabled to the given value.

#Panics

If the given value is out of bounds for content_indexing_disabled. Content indexing is disabled.

pub fn set_content_indexing_disabled_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of content_indexing_disabled to the given value.

#Errors

If the given value is out of bounds for content_indexing_disabled. Content indexing is disabled.

pub fn log_quota_threshold(&self) -> <bool as Specifier>::InOut

Returns the value of log_quota_threshold. An event log entry will be created when the user exceeds his or her assigned quota warning threshold.

pub fn log_quota_threshold_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of log_quota_threshold.

#Errors

If the returned value contains an invalid bit pattern for log_quota_threshold. An event log entry will be created when the user exceeds his or her assigned quota warning threshold.

pub fn with_log_quota_threshold( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of log_quota_threshold set to the given value.

#Panics

If the given value is out of bounds for log_quota_threshold. An event log entry will be created when the user exceeds his or her assigned quota warning threshold.

pub fn with_log_quota_threshold_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of log_quota_threshold set to the given value.

#Errors

If the given value is out of bounds for log_quota_threshold. An event log entry will be created when the user exceeds his or her assigned quota warning threshold.

pub fn set_log_quota_threshold(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of log_quota_threshold to the given value.

#Panics

If the given value is out of bounds for log_quota_threshold. An event log entry will be created when the user exceeds his or her assigned quota warning threshold.

pub fn set_log_quota_threshold_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of log_quota_threshold to the given value.

#Errors

If the given value is out of bounds for log_quota_threshold. An event log entry will be created when the user exceeds his or her assigned quota warning threshold.

pub fn log_quota_limit(&self) -> <bool as Specifier>::InOut

Returns the value of log_quota_limit. An event log entry will be created when the user exceeds the assigned disk quota limit.

pub fn log_quota_limit_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of log_quota_limit.

#Errors

If the returned value contains an invalid bit pattern for log_quota_limit. An event log entry will be created when the user exceeds the assigned disk quota limit.

pub fn with_log_quota_limit(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of log_quota_limit set to the given value.

#Panics

If the given value is out of bounds for log_quota_limit. An event log entry will be created when the user exceeds the assigned disk quota limit.

pub fn with_log_quota_limit_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of log_quota_limit set to the given value.

#Errors

If the given value is out of bounds for log_quota_limit. An event log entry will be created when the user exceeds the assigned disk quota limit.

pub fn set_log_quota_limit(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of log_quota_limit to the given value.

#Panics

If the given value is out of bounds for log_quota_limit. An event log entry will be created when the user exceeds the assigned disk quota limit.

pub fn set_log_quota_limit_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of log_quota_limit to the given value.

#Errors

If the given value is out of bounds for log_quota_limit. An event log entry will be created when the user exceeds the assigned disk quota limit.

pub fn log_volume_threshold(&self) -> <bool as Specifier>::InOut

Returns the value of log_volume_threshold. An event log entry will be created when the volume’s free space threshold is exceeded.

pub fn log_volume_threshold_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of log_volume_threshold.

#Errors

If the returned value contains an invalid bit pattern for log_volume_threshold. An event log entry will be created when the volume’s free space threshold is exceeded.

pub fn with_log_volume_threshold( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of log_volume_threshold set to the given value.

#Panics

If the given value is out of bounds for log_volume_threshold. An event log entry will be created when the volume’s free space threshold is exceeded.

pub fn with_log_volume_threshold_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of log_volume_threshold set to the given value.

#Errors

If the given value is out of bounds for log_volume_threshold. An event log entry will be created when the volume’s free space threshold is exceeded.

pub fn set_log_volume_threshold(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of log_volume_threshold to the given value.

#Panics

If the given value is out of bounds for log_volume_threshold. An event log entry will be created when the volume’s free space threshold is exceeded.

pub fn set_log_volume_threshold_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of log_volume_threshold to the given value.

#Errors

If the given value is out of bounds for log_volume_threshold. An event log entry will be created when the volume’s free space threshold is exceeded.

pub fn log_volume_limit(&self) -> <bool as Specifier>::InOut

Returns the value of log_volume_limit. An event log entry will be created when the volume’s free space limit is exceeded.

pub fn log_volume_limit_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of log_volume_limit.

#Errors

If the returned value contains an invalid bit pattern for log_volume_limit. An event log entry will be created when the volume’s free space limit is exceeded.

pub fn with_log_volume_limit(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of log_volume_limit set to the given value.

#Panics

If the given value is out of bounds for log_volume_limit. An event log entry will be created when the volume’s free space limit is exceeded.

pub fn with_log_volume_limit_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of log_volume_limit set to the given value.

#Errors

If the given value is out of bounds for log_volume_limit. An event log entry will be created when the volume’s free space limit is exceeded.

pub fn set_log_volume_limit(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of log_volume_limit to the given value.

#Panics

If the given value is out of bounds for log_volume_limit. An event log entry will be created when the volume’s free space limit is exceeded.

pub fn set_log_volume_limit_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of log_volume_limit to the given value.

#Errors

If the given value is out of bounds for log_volume_limit. An event log entry will be created when the volume’s free space limit is exceeded.

pub fn quotas_incomplete(&self) -> <bool as Specifier>::InOut

Returns the value of quotas_incomplete. The quota information for the volume is incomplete because it is corrupt, or the system is in the process of rebuilding the quota information. Note: This does not necessarily imply that FILE_VC_QUOTAS_REBUILDING is set. This flag will be ignored if a client attempts to set it.

pub fn quotas_incomplete_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of quotas_incomplete.

#Errors

If the returned value contains an invalid bit pattern for quotas_incomplete. The quota information for the volume is incomplete because it is corrupt, or the system is in the process of rebuilding the quota information. Note: This does not necessarily imply that FILE_VC_QUOTAS_REBUILDING is set. This flag will be ignored if a client attempts to set it.

pub fn with_quotas_incomplete(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of quotas_incomplete set to the given value.

#Panics

If the given value is out of bounds for quotas_incomplete. The quota information for the volume is incomplete because it is corrupt, or the system is in the process of rebuilding the quota information. Note: This does not necessarily imply that FILE_VC_QUOTAS_REBUILDING is set. This flag will be ignored if a client attempts to set it.

pub fn with_quotas_incomplete_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of quotas_incomplete set to the given value.

#Errors

If the given value is out of bounds for quotas_incomplete. The quota information for the volume is incomplete because it is corrupt, or the system is in the process of rebuilding the quota information. Note: This does not necessarily imply that FILE_VC_QUOTAS_REBUILDING is set. This flag will be ignored if a client attempts to set it.

pub fn set_quotas_incomplete(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of quotas_incomplete to the given value.

#Panics

If the given value is out of bounds for quotas_incomplete. The quota information for the volume is incomplete because it is corrupt, or the system is in the process of rebuilding the quota information. Note: This does not necessarily imply that FILE_VC_QUOTAS_REBUILDING is set. This flag will be ignored if a client attempts to set it.

pub fn set_quotas_incomplete_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of quotas_incomplete to the given value.

#Errors

If the given value is out of bounds for quotas_incomplete. The quota information for the volume is incomplete because it is corrupt, or the system is in the process of rebuilding the quota information. Note: This does not necessarily imply that FILE_VC_QUOTAS_REBUILDING is set. This flag will be ignored if a client attempts to set it.

pub fn quotas_rebuilding(&self) -> <bool as Specifier>::InOut

Returns the value of quotas_rebuilding. The file system is rebuilding the quota information for the volume. Note: This does not necessarily imply that FILE_VC_QUOTAS_INCOMPLETE is set. This flag will be ignored if a client attempts to set it.

pub fn quotas_rebuilding_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of quotas_rebuilding.

#Errors

If the returned value contains an invalid bit pattern for quotas_rebuilding. The file system is rebuilding the quota information for the volume. Note: This does not necessarily imply that FILE_VC_QUOTAS_INCOMPLETE is set. This flag will be ignored if a client attempts to set it.

pub fn with_quotas_rebuilding(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of quotas_rebuilding set to the given value.

#Panics

If the given value is out of bounds for quotas_rebuilding. The file system is rebuilding the quota information for the volume. Note: This does not necessarily imply that FILE_VC_QUOTAS_INCOMPLETE is set. This flag will be ignored if a client attempts to set it.

pub fn with_quotas_rebuilding_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of quotas_rebuilding set to the given value.

#Errors

If the given value is out of bounds for quotas_rebuilding. The file system is rebuilding the quota information for the volume. Note: This does not necessarily imply that FILE_VC_QUOTAS_INCOMPLETE is set. This flag will be ignored if a client attempts to set it.

pub fn set_quotas_rebuilding(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of quotas_rebuilding to the given value.

#Panics

If the given value is out of bounds for quotas_rebuilding. The file system is rebuilding the quota information for the volume. Note: This does not necessarily imply that FILE_VC_QUOTAS_INCOMPLETE is set. This flag will be ignored if a client attempts to set it.

pub fn set_quotas_rebuilding_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of quotas_rebuilding to the given value.

#Errors

If the given value is out of bounds for quotas_rebuilding. The file system is rebuilding the quota information for the volume. Note: This does not necessarily imply that FILE_VC_QUOTAS_INCOMPLETE is set. This flag will be ignored if a client attempts to set it.