FileValidDataLengthInformation

Struct FileValidDataLengthInformation 

pub struct FileValidDataLengthInformation {
    pub valid_data_length: u64,
}
set the valid data length information for a file.

A file’s valid data length is the length, in bytes, of the data that has been written to the file. This valid data extends from the beginning of the file to the last byte in the file that has not been zeroed or left uninitialized

MS-FSCC 2.4.49

Fields

valid_data_length: u64

The new valid data length for the file. This parameter must be a positive value that is greater than the current valid data length, but less than or equal to the current file size.