FsDeviceCharacteristics

Struct FsDeviceCharacteristics 

pub struct FsDeviceCharacteristics { /* private fields */ }
Characteristics of a file system volume.

See FileFsDeviceInformation

Implementations

Source

impl FsDeviceCharacteristics

pub const fn new() -> Self

Returns an instance with zero initialized data.

Source

impl FsDeviceCharacteristics

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> Self

Converts the given bytes directly into the bitfield struct.

Source

impl FsDeviceCharacteristics

pub fn removable_media(&self) -> <bool as Specifier>::InOut

Returns the value of removable_media. Indicates that the storage device supports removable media. Notice that this characteristic indicates removable media, not a removable device. For example, drivers for JAZ drive devices specify this characteristic, but drivers for PCMCIA flash disks do not.

pub fn removable_media_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of removable_media.

#Errors

If the returned value contains an invalid bit pattern for removable_media. Indicates that the storage device supports removable media. Notice that this characteristic indicates removable media, not a removable device. For example, drivers for JAZ drive devices specify this characteristic, but drivers for PCMCIA flash disks do not.

pub fn with_removable_media(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of removable_media set to the given value.

#Panics

If the given value is out of bounds for removable_media. Indicates that the storage device supports removable media. Notice that this characteristic indicates removable media, not a removable device. For example, drivers for JAZ drive devices specify this characteristic, but drivers for PCMCIA flash disks do not.

pub fn with_removable_media_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of removable_media set to the given value.

#Errors

If the given value is out of bounds for removable_media. Indicates that the storage device supports removable media. Notice that this characteristic indicates removable media, not a removable device. For example, drivers for JAZ drive devices specify this characteristic, but drivers for PCMCIA flash disks do not.

pub fn set_removable_media(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of removable_media to the given value.

#Panics

If the given value is out of bounds for removable_media. Indicates that the storage device supports removable media. Notice that this characteristic indicates removable media, not a removable device. For example, drivers for JAZ drive devices specify this characteristic, but drivers for PCMCIA flash disks do not.

pub fn set_removable_media_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of removable_media to the given value.

#Errors

If the given value is out of bounds for removable_media. Indicates that the storage device supports removable media. Notice that this characteristic indicates removable media, not a removable device. For example, drivers for JAZ drive devices specify this characteristic, but drivers for PCMCIA flash disks do not.

pub fn read_only(&self) -> <bool as Specifier>::InOut

Returns the value of read_only. Indicates that the device cannot be written to.

pub fn read_only_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of read_only.

#Errors

If the returned value contains an invalid bit pattern for read_only. Indicates that the device cannot be written to.

pub fn with_read_only(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of read_only set to the given value.

#Panics

If the given value is out of bounds for read_only. Indicates that the device cannot be written to.

pub fn with_read_only_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of read_only set to the given value.

#Errors

If the given value is out of bounds for read_only. Indicates that the device cannot be written to.

pub fn set_read_only(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of read_only to the given value.

#Panics

If the given value is out of bounds for read_only. Indicates that the device cannot be written to.

pub fn set_read_only_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of read_only to the given value.

#Errors

If the given value is out of bounds for read_only. Indicates that the device cannot be written to.

pub fn floppy_diskette(&self) -> <bool as Specifier>::InOut

Returns the value of floppy_diskette. Indicates that the device is a floppy disk device.

pub fn floppy_diskette_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of floppy_diskette.

#Errors

If the returned value contains an invalid bit pattern for floppy_diskette. Indicates that the device is a floppy disk device.

pub fn with_floppy_diskette(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of floppy_diskette set to the given value.

#Panics

If the given value is out of bounds for floppy_diskette. Indicates that the device is a floppy disk device.

pub fn with_floppy_diskette_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of floppy_diskette set to the given value.

#Errors

If the given value is out of bounds for floppy_diskette. Indicates that the device is a floppy disk device.

pub fn set_floppy_diskette(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of floppy_diskette to the given value.

#Panics

If the given value is out of bounds for floppy_diskette. Indicates that the device is a floppy disk device.

pub fn set_floppy_diskette_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of floppy_diskette to the given value.

#Errors

If the given value is out of bounds for floppy_diskette. Indicates that the device is a floppy disk device.

pub fn write_once_media(&self) -> <bool as Specifier>::InOut

Returns the value of write_once_media. Indicates that the device supports write-once media.

pub fn write_once_media_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of write_once_media.

#Errors

If the returned value contains an invalid bit pattern for write_once_media. Indicates that the device supports write-once media.

pub fn with_write_once_media(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of write_once_media set to the given value.

#Panics

If the given value is out of bounds for write_once_media. Indicates that the device supports write-once media.

pub fn with_write_once_media_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of write_once_media set to the given value.

#Errors

If the given value is out of bounds for write_once_media. Indicates that the device supports write-once media.

pub fn set_write_once_media(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of write_once_media to the given value.

#Panics

If the given value is out of bounds for write_once_media. Indicates that the device supports write-once media.

pub fn set_write_once_media_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of write_once_media to the given value.

#Errors

If the given value is out of bounds for write_once_media. Indicates that the device supports write-once media.

pub fn remote(&self) -> <bool as Specifier>::InOut

Returns the value of remote. Indicates that the volume is for a remote file system like SMB or CIFS.

pub fn remote_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of remote.

#Errors

If the returned value contains an invalid bit pattern for remote. Indicates that the volume is for a remote file system like SMB or CIFS.

pub fn with_remote(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of remote set to the given value.

#Panics

If the given value is out of bounds for remote. Indicates that the volume is for a remote file system like SMB or CIFS.

pub fn with_remote_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of remote set to the given value.

#Errors

If the given value is out of bounds for remote. Indicates that the volume is for a remote file system like SMB or CIFS.

pub fn set_remote(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of remote to the given value.

#Panics

If the given value is out of bounds for remote. Indicates that the volume is for a remote file system like SMB or CIFS.

pub fn set_remote_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of remote to the given value.

#Errors

If the given value is out of bounds for remote. Indicates that the volume is for a remote file system like SMB or CIFS.

pub fn device_is_mounted(&self) -> <bool as Specifier>::InOut

Returns the value of device_is_mounted. Indicates that a file system is mounted on the device.

pub fn device_is_mounted_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of device_is_mounted.

#Errors

If the returned value contains an invalid bit pattern for device_is_mounted. Indicates that a file system is mounted on the device.

pub fn with_device_is_mounted(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of device_is_mounted set to the given value.

#Panics

If the given value is out of bounds for device_is_mounted. Indicates that a file system is mounted on the device.

pub fn with_device_is_mounted_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of device_is_mounted set to the given value.

#Errors

If the given value is out of bounds for device_is_mounted. Indicates that a file system is mounted on the device.

pub fn set_device_is_mounted(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of device_is_mounted to the given value.

#Panics

If the given value is out of bounds for device_is_mounted. Indicates that a file system is mounted on the device.

pub fn set_device_is_mounted_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of device_is_mounted to the given value.

#Errors

If the given value is out of bounds for device_is_mounted. Indicates that a file system is mounted on the device.

pub fn virtual_volume(&self) -> <bool as Specifier>::InOut

Returns the value of virtual_volume. Indicates that the volume does not directly reside on storage media but resides on some other type of media (memory for example).

pub fn virtual_volume_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of virtual_volume.

#Errors

If the returned value contains an invalid bit pattern for virtual_volume. Indicates that the volume does not directly reside on storage media but resides on some other type of media (memory for example).

pub fn with_virtual_volume(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of virtual_volume set to the given value.

#Panics

If the given value is out of bounds for virtual_volume. Indicates that the volume does not directly reside on storage media but resides on some other type of media (memory for example).

pub fn with_virtual_volume_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of virtual_volume set to the given value.

#Errors

If the given value is out of bounds for virtual_volume. Indicates that the volume does not directly reside on storage media but resides on some other type of media (memory for example).

pub fn set_virtual_volume(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of virtual_volume to the given value.

#Panics

If the given value is out of bounds for virtual_volume. Indicates that the volume does not directly reside on storage media but resides on some other type of media (memory for example).

pub fn set_virtual_volume_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of virtual_volume to the given value.

#Errors

If the given value is out of bounds for virtual_volume. Indicates that the volume does not directly reside on storage media but resides on some other type of media (memory for example).

pub fn secure_open(&self) -> <bool as Specifier>::InOut

Returns the value of secure_open. By default, volumes do not check the ACL associated with the volume, but instead use the ACLs associated with individual files on the volume. When this flag is set the volume ACL is also checked.

pub fn secure_open_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of secure_open.

#Errors

If the returned value contains an invalid bit pattern for secure_open. By default, volumes do not check the ACL associated with the volume, but instead use the ACLs associated with individual files on the volume. When this flag is set the volume ACL is also checked.

pub fn with_secure_open(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of secure_open set to the given value.

#Panics

If the given value is out of bounds for secure_open. By default, volumes do not check the ACL associated with the volume, but instead use the ACLs associated with individual files on the volume. When this flag is set the volume ACL is also checked.

pub fn with_secure_open_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of secure_open set to the given value.

#Errors

If the given value is out of bounds for secure_open. By default, volumes do not check the ACL associated with the volume, but instead use the ACLs associated with individual files on the volume. When this flag is set the volume ACL is also checked.

pub fn set_secure_open(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of secure_open to the given value.

#Panics

If the given value is out of bounds for secure_open. By default, volumes do not check the ACL associated with the volume, but instead use the ACLs associated with individual files on the volume. When this flag is set the volume ACL is also checked.

pub fn set_secure_open_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of secure_open to the given value.

#Errors

If the given value is out of bounds for secure_open. By default, volumes do not check the ACL associated with the volume, but instead use the ACLs associated with individual files on the volume. When this flag is set the volume ACL is also checked.

pub fn ts(&self) -> <bool as Specifier>::InOut

Returns the value of ts. Indicates that the device object is part of a Terminal Services device stack. See [MS-RDPBCGR] for more information.

pub fn ts_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of ts.

#Errors

If the returned value contains an invalid bit pattern for ts. Indicates that the device object is part of a Terminal Services device stack. See [MS-RDPBCGR] for more information.

pub fn with_ts(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of ts set to the given value.

#Panics

If the given value is out of bounds for ts. Indicates that the device object is part of a Terminal Services device stack. See [MS-RDPBCGR] for more information.

pub fn with_ts_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of ts set to the given value.

#Errors

If the given value is out of bounds for ts. Indicates that the device object is part of a Terminal Services device stack. See [MS-RDPBCGR] for more information.

pub fn set_ts(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of ts to the given value.

#Panics

If the given value is out of bounds for ts. Indicates that the device object is part of a Terminal Services device stack. See [MS-RDPBCGR] for more information.

pub fn set_ts_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of ts to the given value.

#Errors

If the given value is out of bounds for ts. Indicates that the device object is part of a Terminal Services device stack. See [MS-RDPBCGR] for more information.

pub fn webda(&self) -> <bool as Specifier>::InOut

Returns the value of webda. Indicates that a web-based Distributed Authoring and Versioning (WebDAV) file system is mounted on the device. See [MS-WDVME] for more information.

pub fn webda_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of webda.

#Errors

If the returned value contains an invalid bit pattern for webda. Indicates that a web-based Distributed Authoring and Versioning (WebDAV) file system is mounted on the device. See [MS-WDVME] for more information.

pub fn with_webda(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of webda set to the given value.

#Panics

If the given value is out of bounds for webda. Indicates that a web-based Distributed Authoring and Versioning (WebDAV) file system is mounted on the device. See [MS-WDVME] for more information.

pub fn with_webda_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of webda set to the given value.

#Errors

If the given value is out of bounds for webda. Indicates that a web-based Distributed Authoring and Versioning (WebDAV) file system is mounted on the device. See [MS-WDVME] for more information.

pub fn set_webda(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of webda to the given value.

#Panics

If the given value is out of bounds for webda. Indicates that a web-based Distributed Authoring and Versioning (WebDAV) file system is mounted on the device. See [MS-WDVME] for more information.

pub fn set_webda_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of webda to the given value.

#Errors

If the given value is out of bounds for webda. Indicates that a web-based Distributed Authoring and Versioning (WebDAV) file system is mounted on the device. See [MS-WDVME] for more information.

pub fn allow_appcontainer_traversal(&self) -> <bool as Specifier>::InOut

Returns the value of allow_appcontainer_traversal. The IO Manager normally performs a full security check for traverse access on every file open when the client is an appcontainer. Setting of this flag bypasses this enforced traverse access check if the client token already has traverse privileges.

pub fn allow_appcontainer_traversal_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of allow_appcontainer_traversal.

#Errors

If the returned value contains an invalid bit pattern for allow_appcontainer_traversal. The IO Manager normally performs a full security check for traverse access on every file open when the client is an appcontainer. Setting of this flag bypasses this enforced traverse access check if the client token already has traverse privileges.

pub fn with_allow_appcontainer_traversal( self, new_val: <bool as Specifier>::InOut, ) -> Self

Returns a copy of the bitfield with the value of allow_appcontainer_traversal set to the given value.

#Panics

If the given value is out of bounds for allow_appcontainer_traversal. The IO Manager normally performs a full security check for traverse access on every file open when the client is an appcontainer. Setting of this flag bypasses this enforced traverse access check if the client token already has traverse privileges.

pub fn with_allow_appcontainer_traversal_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of allow_appcontainer_traversal set to the given value.

#Errors

If the given value is out of bounds for allow_appcontainer_traversal. The IO Manager normally performs a full security check for traverse access on every file open when the client is an appcontainer. Setting of this flag bypasses this enforced traverse access check if the client token already has traverse privileges.

pub fn set_allow_appcontainer_traversal( &mut self, new_val: <bool as Specifier>::InOut, )

Sets the value of allow_appcontainer_traversal to the given value.

#Panics

If the given value is out of bounds for allow_appcontainer_traversal. The IO Manager normally performs a full security check for traverse access on every file open when the client is an appcontainer. Setting of this flag bypasses this enforced traverse access check if the client token already has traverse privileges.

pub fn set_allow_appcontainer_traversal_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of allow_appcontainer_traversal to the given value.

#Errors

If the given value is out of bounds for allow_appcontainer_traversal. The IO Manager normally performs a full security check for traverse access on every file open when the client is an appcontainer. Setting of this flag bypasses this enforced traverse access check if the client token already has traverse privileges.

pub fn portable(&self) -> <bool as Specifier>::InOut

Returns the value of portable. Indicates that the given device resides on a portable bus like USB or Firewire and that the entire device (not just the media) can be removed from the system.

pub fn portable_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of portable.

#Errors

If the returned value contains an invalid bit pattern for portable. Indicates that the given device resides on a portable bus like USB or Firewire and that the entire device (not just the media) can be removed from the system.

pub fn with_portable(self, new_val: <bool as Specifier>::InOut) -> Self

Returns a copy of the bitfield with the value of portable set to the given value.

#Panics

If the given value is out of bounds for portable. Indicates that the given device resides on a portable bus like USB or Firewire and that the entire device (not just the media) can be removed from the system.

pub fn with_portable_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>

Returns a copy of the bitfield with the value of portable set to the given value.

#Errors

If the given value is out of bounds for portable. Indicates that the given device resides on a portable bus like USB or Firewire and that the entire device (not just the media) can be removed from the system.

pub fn set_portable(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of portable to the given value.

#Panics

If the given value is out of bounds for portable. Indicates that the given device resides on a portable bus like USB or Firewire and that the entire device (not just the media) can be removed from the system.

pub fn set_portable_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of portable to the given value.

#Errors

If the given value is out of bounds for portable. Indicates that the given device resides on a portable bus like USB or Firewire and that the entire device (not just the media) can be removed from the system.