pub type FileFullEaInformation = ChainedItemList<FileFullEaInformationInner, 4>;Aliased Type
pub struct FileFullEaInformation { /* private fields */ }Trait Implementations
Sourceimpl QueryFileInfoValue for FileFullEaInformation
impl QueryFileInfoValue for FileFullEaInformation
const CLASS_ID: QueryFileInfoClass = QueryFileInfoClass::FullEaInformation
Sourceimpl SetFileInfoValue for FileFullEaInformation
impl SetFileInfoValue for FileFullEaInformation
const CLASS_ID: SetFileInfoClass = SetFileInfoClass::FullEaInformation
Sourceimpl TryFrom<QueryFileInfo> for FileFullEaInformation
impl TryFrom<QueryFileInfo> for FileFullEaInformation
Sourcetype Error = SmbFsccError
type Error = SmbFsccError
The type returned in the event of a conversion error.
Sourceimpl TryFrom<SetFileInfo> for FileFullEaInformation
impl TryFrom<SetFileInfo> for FileFullEaInformation
Sourcetype Error = SmbFsccError
type Error = SmbFsccError
The type returned in the event of a conversion error.