NotifyAction

Enum NotifyAction 

pub enum NotifyAction {
    Added = 1,
    Removed = 2,
    Modified = 3,
    RenamedOldName = 4,
    RenamedNewName = 5,
    AddedStream = 6,
    RemovedStream = 7,
    ModifiedStream = 8,
    RemovedByDelete = 9,
    IdNotTunnelled = 10,
    TunnelledIdCollision = 11,
}
Variants



Added = 1

The file was renamed, and FileName contains the new name. This notification is only sent when the rename operation changes the directory the file resides in. The client will also receive a FILE_ACTION_REMOVED notification. This notification will not be received if the file is renamed within a directory.



Removed = 2

The file was renamed, and FileName contains the old name. This notification is only sent when the rename operation changes the directory the file resides in. The client will also receive a FILE_ACTION_ADDED notification. This notification will not be received if the file is renamed within a directory.



Modified = 3

The file was modified. This can be a change to the data or attributes of the file.



RenamedOldName = 4

The file was renamed, and FileName contains the old name. This notification is only sent when the rename operation does not change the directory the file resides in. The client will also receive a FILE_ACTION_RENAMED_NEW_NAME notification. This notification will not be received if the file is renamed to a different directory.



RenamedNewName = 5

The file was renamed, and FileName contains the new name. This notification is only sent when the rename operation does not change the directory the file resides in. The client will also receive a FILE_ACTION_RENAMED_OLD_NAME notification. This notification will not be received if the file is renamed to a different directory.



AddedStream = 6

The file was added to a named stream.



RemovedStream = 7

The file was removed from the named stream.



ModifiedStream = 8

The file was modified. This can be a change to the data or attributes of the file.



RemovedByDelete = 9

An object ID was removed because the file the object ID referred to was deleted.

This notification is only sent when the directory being monitored is the special directory “$Extend$ObjId:$O:$INDEX_ALLOCATION”.



IdNotTunnelled = 10

An attempt to tunnel object ID information to a file being created or renamed failed because the object ID is in use by another file on the same volume.

This notification is only sent when the directory being monitored is the special directory “$Extend$ObjId:$O:$INDEX_ALLOCATION”.



TunnelledIdCollision = 11

An attempt to tunnel object ID information to a file being renamed failed because the file already has an object ID.

This notification is only sent when the directory being monitored is the special directory “$Extend$ObjId:$O:$INDEX_ALLOCATION”.