pub enum PipeCompletionMode {
Queue = 0,
Complete = 1,
}Expand description
Named pipe completion mode values.
Variants
Queue = 0
Blocking mode is enabled. When the pipe handle is specified in a call to the ReadFile or WriteFile function, the operations are not completed until there is data to read or all data is written.
Complete = 1
Nonblocking mode is enabled. When the pipe handle is specified in a call to the ReadFile or WriteFile function, the operations complete immediately.