#[repr(u32)]pub enum ReparseTag {
Show 55 variants
ReservedZero = 0,
ReservedOne = 1,
ReservedTwo = 2,
MountPoint = 2_684_354_563,
HSM = 3_221_225_476,
DriveExtender = 2_147_483_653,
HSM2 = 2_147_483_654,
SIS = 2_147_483_655,
WIM = 2_147_483_656,
CSV = 2_147_483_657,
DFS = 2_147_483_658,
FilterManager = 2_147_483_659,
Symlink = 2_684_354_572,
IISCache = 2_684_354_576,
DFSR = 2_147_483_666,
Dedup = 2_147_483_667,
Appxstrm = 3_221_225_492,
NFS = 2_147_483_668,
FilePlaceholder = 2_147_483_669,
DFM = 2_147_483_670,
WOF = 2_147_483_671,
WCI = 2_147_483_672,
Wci1 = 2_415_923_224,
GlobalReparse = 2_684_354_585,
Cloud = 2_415_919_130,
Cloud1 = 2_415_923_226,
Cloud2 = 2_415_927_322,
Cloud3 = 2_415_931_418,
Cloud4 = 2_415_935_514,
Cloud5 = 2_415_939_610,
Cloud6 = 2_415_943_706,
Cloud7 = 2_415_947_802,
Cloud8 = 2_415_951_898,
Cloud9 = 2_415_955_994,
CloudA = 2_415_960_090,
CloudB = 2_415_964_186,
CloudC = 2_415_968_282,
CloudD = 2_415_972_378,
CloudE = 2_415_976_474,
CloudF = 2_415_980_570,
Appexeclink = 2_147_483_675,
Projfs = 2_415_919_132,
LxSymlink = 2_684_354_589,
StorageSync = 2_147_483_678,
StorageSyncFolder = 2_415_919_143,
WciTombstone = 2_684_354_591,
Unhandled = 2_147_483_680,
Onedrive = 2_147_483_681,
ProjfsTombstone = 2_684_354_594,
AfUnix = 2_147_483_683,
LxFifo = 2_147_483_684,
LxChr = 2_147_483_685,
LxBlk = 2_147_483_686,
WciLink = 2_684_354_599,
WciLink1 = 2_684_358_695,
}Expand description
Reparse Tag Values
Each reparse point has a reparse tag. The reparse tag uniquely identifies the owner of that reparse point. The owner is the implementer of the file system filter driver associated with a reparse tag.
Variants
ReservedZero = 0
Reserved reparse tag value.
ReservedOne = 1
Reserved reparse tag value.
ReservedTwo = 2
Reserved reparse tag value.
MountPoint = 2_684_354_563
Used for mount point support, specified in section 2.1.2.5.
HSM = 3_221_225_476
Obsolete. Used by legacy Hierarchical Storage Manager Product.
DriveExtender = 2_147_483_653
Home server drive extender.<3>
HSM2 = 2_147_483_654
Obsolete. Used by legacy Hierarchical Storage Manager Product.
SIS = 2_147_483_655
Used by single-instance storage (SIS) filter driver. Server-side interpretation only, not meaningful over the wire.
WIM = 2_147_483_656
Used by the WIM Mount filter. Server-side interpretation only, not meaningful over the wire.
CSV = 2_147_483_657
Obsolete. Used by Clustered Shared Volumes (CSV) version 1 in Windows Server 2008 R2 operating system. Server-side interpretation only, not meaningful over the wire.
DFS = 2_147_483_658
Used by the DFS filter. The DFS is described in the Distributed File System (DFS): Referral Protocol Specification [MS-DFSC]. Server-side interpretation only, not meaningful over the wire.
FilterManager = 2_147_483_659
Used by filter manager test harness.<4>
Symlink = 2_684_354_572
Used for symbolic link support. See section 2.1.2.4.
IISCache = 2_684_354_576
Used by Microsoft Internet Information Services (IIS) caching. Server-side interpretation only, not meaningful over the wire.
DFSR = 2_147_483_666
Used by the DFS filter. The DFS is described in [MS-DFSC]. Server-side interpretation only, not meaningful over the wire.
Dedup = 2_147_483_667
Used by the Data Deduplication (Dedup) filter. Server-side interpretation only, not meaningful over the wire.
Appxstrm = 3_221_225_492
Not used.
NFS = 2_147_483_668
Used by the Network File System (NFS) component. Server-side interpretation only, not meaningful over the wire.
FilePlaceholder = 2_147_483_669
Obsolete. Used by Windows Shell for legacy placeholder files in Windows 8.1. Server-side interpretation only, not meaningful over the wire.
DFM = 2_147_483_670
Used by the Dynamic File filter. Server-side interpretation only, not meaningful over the wire.
WOF = 2_147_483_671
Used by the Windows Overlay filter, for either WIMBoot or single-file compression. Server-side interpretation only, not meaningful over the wire.
WCI = 2_147_483_672
Used by the Windows Container Isolation filter. Server-side interpretation only, not meaningful over the wire.
Wci1 = 2_415_923_224
Used by the Windows Container Isolation filter. Server-side interpretation only, not meaningful over the wire.
GlobalReparse = 2_684_354_585
Used by NPFS to indicate a named pipe symbolic link from a server silo into the host silo. Server-side interpretation only, not meaningful over the wire.
Cloud = 2_415_919_130
Used by the Cloud Files filter, for files managed by a sync engine such as Microsoft OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud1 = 2_415_923_226
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud2 = 2_415_927_322
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud3 = 2_415_931_418
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud4 = 2_415_935_514
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud5 = 2_415_939_610
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud6 = 2_415_943_706
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud7 = 2_415_947_802
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud8 = 2_415_951_898
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Cloud9 = 2_415_955_994
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
CloudA = 2_415_960_090
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
CloudB = 2_415_964_186
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
CloudC = 2_415_968_282
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
CloudD = 2_415_972_378
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
CloudE = 2_415_976_474
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
CloudF = 2_415_980_570
Used by the Cloud Files filter, for files managed by a sync engine such as OneDrive. Server-side interpretation only, not meaningful over the wire.
Appexeclink = 2_147_483_675
Used by Universal Windows Platform (UWP) packages to encode information that allows the application to be launched by CreateProcess. Server-side interpretation only, not meaningful over the wire.
Projfs = 2_415_919_132
Used by the Windows Projected File System filter, for files managed by a user mode provider such as VFS for Git. Server-side interpretation only, not meaningful over the wire.
LxSymlink = 2_684_354_589
Used by the Windows Subsystem for Linux (WSL) to represent a UNIX symbolic link. Server-side interpretation only, not meaningful over the wire.
StorageSync = 2_147_483_678
Used by the Azure File Sync (AFS) filter. Server-side interpretation only, not meaningful over the wire.
StorageSyncFolder = 2_415_919_143
Used by the Azure File Sync (AFS) filter for folder. Server-side interpretation only, not meaningful over the wire.
WciTombstone = 2_684_354_591
Used by the Windows Container Isolation filter. Server-side interpretation only, not meaningful over the wire.
Unhandled = 2_147_483_680
Used by the Windows Container Isolation filter. Server-side interpretation only, not meaningful over the wire.
Onedrive = 2_147_483_681
Not used.
ProjfsTombstone = 2_684_354_594
Used by the Windows Projected File System filter, for files managed by a user mode provider such as VFS for Git. Server-side interpretation only, not meaningful over the wire.
AfUnix = 2_147_483_683
Used by the Windows Subsystem for Linux (WSL) to represent a UNIX domain socket. Server-side interpretation only, not meaningful over the wire.
LxFifo = 2_147_483_684
Used by the Windows Subsystem for Linux (WSL) to represent a UNIX FIFO (named pipe). Server-side interpretation only, not meaningful over the wire.
LxChr = 2_147_483_685
Used by the Windows Subsystem for Linux (WSL) to represent a UNIX character special file. Server-side interpretation only, not meaningful over the wire.
LxBlk = 2_147_483_686
Used by the Windows Subsystem for Linux (WSL) to represent a UNIX block special file. Server-side interpretation only, not meaningful over the wire.
WciLink = 2_684_354_599
Used by the Windows Container Isolation filter. Server-side interpretation only, not meaningful over the wire.
WciLink1 = 2_684_358_695
Used by the Windows Container Isolation filter. Server-side interpretation only, not meaningful over the wire.