pub struct EaFlags { /* private fields */ }Expand description
Extended Attribute (EA) Flags
Implementations
Sourceimpl EaFlags
impl EaFlags
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> Self
pub const fn from_bytes(bytes: [u8; 1]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl EaFlags
impl EaFlags
Sourcepub fn file_need_ea(&self) -> <bool as Specifier>::InOut
pub fn file_need_ea(&self) -> <bool as Specifier>::InOut
Returns the value of file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.
Sourcepub fn file_need_ea_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_need_ea_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_need_ea.
#Errors
If the returned value contains an invalid bit pattern for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.
Sourcepub fn with_file_need_ea(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_need_ea(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_need_ea set to the given value.
#Panics
If the given value is out of bounds for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.
Sourcepub fn with_file_need_ea_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_need_ea_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_need_ea set to the given value.
#Errors
If the given value is out of bounds for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.
Sourcepub fn set_file_need_ea(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_need_ea(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_need_ea to the given value.
#Panics
If the given value is out of bounds for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.
Sourcepub fn set_file_need_ea_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_need_ea_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_need_ea to the given value.
#Errors
If the given value is out of bounds for file_need_ea. If this flag is set, the file to which the EA belongs cannot be interpreted by applications that do not understand EAs.