pub struct FileAccessMask { /* private fields */ }Implementations
Sourceimpl FileAccessMask
impl FileAccessMask
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl FileAccessMask
impl FileAccessMask
Sourcepub fn file_read_data(&self) -> <bool as Specifier>::InOut
pub fn file_read_data(&self) -> <bool as Specifier>::InOut
Returns the value of file_read_data.
Sourcepub fn file_read_data_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_read_data_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_read_data.
#Errors
If the returned value contains an invalid bit pattern for file_read_data.
Sourcepub fn with_file_read_data(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_read_data(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_read_data set to the given value.
#Panics
If the given value is out of bounds for file_read_data.
Sourcepub fn with_file_read_data_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_read_data_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_read_data set to the given value.
#Errors
If the given value is out of bounds for file_read_data.
Sourcepub fn set_file_read_data(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_read_data(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_read_data to the given value.
#Panics
If the given value is out of bounds for file_read_data.
Sourcepub fn set_file_read_data_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_read_data_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_read_data to the given value.
#Errors
If the given value is out of bounds for file_read_data.
Sourcepub fn file_write_data(&self) -> <bool as Specifier>::InOut
pub fn file_write_data(&self) -> <bool as Specifier>::InOut
Returns the value of file_write_data.
Sourcepub fn file_write_data_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_write_data_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_write_data.
#Errors
If the returned value contains an invalid bit pattern for file_write_data.
Sourcepub fn with_file_write_data(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_write_data(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_write_data set to the given value.
#Panics
If the given value is out of bounds for file_write_data.
Sourcepub fn with_file_write_data_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_write_data_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_write_data set to the given value.
#Errors
If the given value is out of bounds for file_write_data.
Sourcepub fn set_file_write_data(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_write_data(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_write_data to the given value.
#Panics
If the given value is out of bounds for file_write_data.
Sourcepub fn set_file_write_data_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_write_data_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_write_data to the given value.
#Errors
If the given value is out of bounds for file_write_data.
Sourcepub fn file_append_data(&self) -> <bool as Specifier>::InOut
pub fn file_append_data(&self) -> <bool as Specifier>::InOut
Returns the value of file_append_data.
Sourcepub fn file_append_data_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_append_data_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_append_data.
#Errors
If the returned value contains an invalid bit pattern for file_append_data.
Sourcepub fn with_file_append_data(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_append_data(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_append_data set to the given value.
#Panics
If the given value is out of bounds for file_append_data.
Sourcepub fn with_file_append_data_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_append_data_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_append_data set to the given value.
#Errors
If the given value is out of bounds for file_append_data.
Sourcepub fn set_file_append_data(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_append_data(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_append_data to the given value.
#Panics
If the given value is out of bounds for file_append_data.
Sourcepub fn set_file_append_data_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_append_data_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_append_data to the given value.
#Errors
If the given value is out of bounds for file_append_data.
Sourcepub fn file_read_ea(&self) -> <bool as Specifier>::InOut
pub fn file_read_ea(&self) -> <bool as Specifier>::InOut
Returns the value of file_read_ea.
Sourcepub fn file_read_ea_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_read_ea_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_read_ea.
#Errors
If the returned value contains an invalid bit pattern for file_read_ea.
Sourcepub fn with_file_read_ea(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_read_ea(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_read_ea set to the given value.
#Panics
If the given value is out of bounds for file_read_ea.
Sourcepub fn with_file_read_ea_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_read_ea_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_read_ea set to the given value.
#Errors
If the given value is out of bounds for file_read_ea.
Sourcepub fn set_file_read_ea(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_read_ea(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_read_ea to the given value.
#Panics
If the given value is out of bounds for file_read_ea.
Sourcepub fn set_file_read_ea_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_read_ea_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_read_ea to the given value.
#Errors
If the given value is out of bounds for file_read_ea.
Sourcepub fn file_write_ea(&self) -> <bool as Specifier>::InOut
pub fn file_write_ea(&self) -> <bool as Specifier>::InOut
Returns the value of file_write_ea.
Sourcepub fn file_write_ea_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_write_ea_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_write_ea.
#Errors
If the returned value contains an invalid bit pattern for file_write_ea.
Sourcepub fn with_file_write_ea(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_write_ea(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_write_ea set to the given value.
#Panics
If the given value is out of bounds for file_write_ea.
Sourcepub fn with_file_write_ea_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_write_ea_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_write_ea set to the given value.
#Errors
If the given value is out of bounds for file_write_ea.
Sourcepub fn set_file_write_ea(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_write_ea(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_write_ea to the given value.
#Panics
If the given value is out of bounds for file_write_ea.
Sourcepub fn set_file_write_ea_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_write_ea_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_write_ea to the given value.
#Errors
If the given value is out of bounds for file_write_ea.
Sourcepub fn file_execute(&self) -> <bool as Specifier>::InOut
pub fn file_execute(&self) -> <bool as Specifier>::InOut
Returns the value of file_execute.
Sourcepub fn file_execute_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_execute_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_execute.
#Errors
If the returned value contains an invalid bit pattern for file_execute.
Sourcepub fn with_file_execute(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_execute(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_execute set to the given value.
#Panics
If the given value is out of bounds for file_execute.
Sourcepub fn with_file_execute_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_execute_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_execute set to the given value.
#Errors
If the given value is out of bounds for file_execute.
Sourcepub fn set_file_execute(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_execute(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_execute to the given value.
#Panics
If the given value is out of bounds for file_execute.
Sourcepub fn set_file_execute_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_execute_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_execute to the given value.
#Errors
If the given value is out of bounds for file_execute.
Sourcepub fn file_delete_child(&self) -> <bool as Specifier>::InOut
pub fn file_delete_child(&self) -> <bool as Specifier>::InOut
Returns the value of file_delete_child.
Sourcepub fn file_delete_child_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_delete_child_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_delete_child.
#Errors
If the returned value contains an invalid bit pattern for file_delete_child.
Sourcepub fn with_file_delete_child(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_delete_child(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_delete_child set to the given value.
#Panics
If the given value is out of bounds for file_delete_child.
Sourcepub fn with_file_delete_child_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_delete_child_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_delete_child set to the given value.
#Errors
If the given value is out of bounds for file_delete_child.
Sourcepub fn set_file_delete_child(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_delete_child(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_delete_child to the given value.
#Panics
If the given value is out of bounds for file_delete_child.
Sourcepub fn set_file_delete_child_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_delete_child_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_delete_child to the given value.
#Errors
If the given value is out of bounds for file_delete_child.
Sourcepub fn file_read_attributes(&self) -> <bool as Specifier>::InOut
pub fn file_read_attributes(&self) -> <bool as Specifier>::InOut
Returns the value of file_read_attributes.
Sourcepub fn file_read_attributes_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_read_attributes_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_read_attributes.
#Errors
If the returned value contains an invalid bit pattern for file_read_attributes.
Sourcepub fn with_file_read_attributes(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_file_read_attributes( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of file_read_attributes set to the given value.
#Panics
If the given value is out of bounds for file_read_attributes.
Sourcepub fn with_file_read_attributes_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_read_attributes_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_read_attributes set to the given value.
#Errors
If the given value is out of bounds for file_read_attributes.
Sourcepub fn set_file_read_attributes(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_read_attributes(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_read_attributes to the given value.
#Panics
If the given value is out of bounds for file_read_attributes.
Sourcepub fn set_file_read_attributes_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_read_attributes_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_read_attributes to the given value.
#Errors
If the given value is out of bounds for file_read_attributes.
Sourcepub fn file_write_attributes(&self) -> <bool as Specifier>::InOut
pub fn file_write_attributes(&self) -> <bool as Specifier>::InOut
Returns the value of file_write_attributes.
Sourcepub fn file_write_attributes_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_write_attributes_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_write_attributes.
#Errors
If the returned value contains an invalid bit pattern for file_write_attributes.
Sourcepub fn with_file_write_attributes(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_file_write_attributes( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of file_write_attributes set to the given value.
#Panics
If the given value is out of bounds for file_write_attributes.
Sourcepub fn with_file_write_attributes_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_write_attributes_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_write_attributes set to the given value.
#Errors
If the given value is out of bounds for file_write_attributes.
Sourcepub fn set_file_write_attributes(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_write_attributes(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_write_attributes to the given value.
#Panics
If the given value is out of bounds for file_write_attributes.
Sourcepub fn set_file_write_attributes_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_write_attributes_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_write_attributes to the given value.
#Errors
If the given value is out of bounds for file_write_attributes.
Sourcepub fn delete_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn delete_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of delete.
#Errors
If the returned value contains an invalid bit pattern for delete.
Sourcepub fn with_delete(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_delete(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of delete set to the given value.
#Panics
If the given value is out of bounds for delete.
Sourcepub fn with_delete_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_delete_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of delete set to the given value.
#Errors
If the given value is out of bounds for delete.
Sourcepub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of delete to the given value.
#Panics
If the given value is out of bounds for delete.
Sourcepub fn set_delete_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_delete_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of delete to the given value.
#Errors
If the given value is out of bounds for delete.
Sourcepub fn read_control(&self) -> <bool as Specifier>::InOut
pub fn read_control(&self) -> <bool as Specifier>::InOut
Returns the value of read_control.
Sourcepub fn read_control_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn read_control_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of read_control.
#Errors
If the returned value contains an invalid bit pattern for read_control.
Sourcepub fn with_read_control(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_read_control(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of read_control set to the given value.
#Panics
If the given value is out of bounds for read_control.
Sourcepub fn with_read_control_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_read_control_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of read_control set to the given value.
#Errors
If the given value is out of bounds for read_control.
Sourcepub fn set_read_control(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_read_control(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of read_control to the given value.
#Panics
If the given value is out of bounds for read_control.
Sourcepub fn set_read_control_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_read_control_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of read_control to the given value.
#Errors
If the given value is out of bounds for read_control.
Sourcepub fn write_dacl(&self) -> <bool as Specifier>::InOut
pub fn write_dacl(&self) -> <bool as Specifier>::InOut
Returns the value of write_dacl.
Sourcepub fn write_dacl_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_dacl_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_dacl.
#Errors
If the returned value contains an invalid bit pattern for write_dacl.
Sourcepub fn with_write_dacl(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_dacl(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_dacl set to the given value.
#Panics
If the given value is out of bounds for write_dacl.
Sourcepub fn with_write_dacl_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_dacl_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_dacl set to the given value.
#Errors
If the given value is out of bounds for write_dacl.
Sourcepub fn set_write_dacl(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_dacl(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_dacl to the given value.
#Panics
If the given value is out of bounds for write_dacl.
Sourcepub fn set_write_dacl_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_dacl_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_dacl to the given value.
#Errors
If the given value is out of bounds for write_dacl.
Sourcepub fn write_owner(&self) -> <bool as Specifier>::InOut
pub fn write_owner(&self) -> <bool as Specifier>::InOut
Returns the value of write_owner.
Sourcepub fn write_owner_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn write_owner_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of write_owner.
#Errors
If the returned value contains an invalid bit pattern for write_owner.
Sourcepub fn with_write_owner(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_write_owner(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of write_owner set to the given value.
#Panics
If the given value is out of bounds for write_owner.
Sourcepub fn with_write_owner_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_write_owner_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of write_owner set to the given value.
#Errors
If the given value is out of bounds for write_owner.
Sourcepub fn set_write_owner(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_write_owner(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of write_owner to the given value.
#Panics
If the given value is out of bounds for write_owner.
Sourcepub fn set_write_owner_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_write_owner_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of write_owner to the given value.
#Errors
If the given value is out of bounds for write_owner.
Sourcepub fn synchronize(&self) -> <bool as Specifier>::InOut
pub fn synchronize(&self) -> <bool as Specifier>::InOut
Returns the value of synchronize.
Sourcepub fn synchronize_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn synchronize_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of synchronize.
#Errors
If the returned value contains an invalid bit pattern for synchronize.
Sourcepub fn with_synchronize(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_synchronize(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of synchronize set to the given value.
#Panics
If the given value is out of bounds for synchronize.
Sourcepub fn with_synchronize_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_synchronize_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of synchronize set to the given value.
#Errors
If the given value is out of bounds for synchronize.
Sourcepub fn set_synchronize(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_synchronize(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of synchronize to the given value.
#Panics
If the given value is out of bounds for synchronize.
Sourcepub fn set_synchronize_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_synchronize_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of synchronize to the given value.
#Errors
If the given value is out of bounds for synchronize.
Sourcepub fn access_system_security(&self) -> <bool as Specifier>::InOut
pub fn access_system_security(&self) -> <bool as Specifier>::InOut
Returns the value of access_system_security.
Sourcepub fn access_system_security_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn access_system_security_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of access_system_security.
#Errors
If the returned value contains an invalid bit pattern for access_system_security.
Sourcepub fn with_access_system_security(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_access_system_security( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of access_system_security set to the given value.
#Panics
If the given value is out of bounds for access_system_security.
Sourcepub fn with_access_system_security_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_access_system_security_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of access_system_security set to the given value.
#Errors
If the given value is out of bounds for access_system_security.
Sourcepub fn set_access_system_security(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_access_system_security( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of access_system_security to the given value.
#Panics
If the given value is out of bounds for access_system_security.
Sourcepub fn set_access_system_security_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_access_system_security_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of access_system_security to the given value.
#Errors
If the given value is out of bounds for access_system_security.
Sourcepub fn maximum_allowed(&self) -> <bool as Specifier>::InOut
pub fn maximum_allowed(&self) -> <bool as Specifier>::InOut
Returns the value of maximum_allowed.
Sourcepub fn maximum_allowed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn maximum_allowed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of maximum_allowed.
#Errors
If the returned value contains an invalid bit pattern for maximum_allowed.
Sourcepub fn with_maximum_allowed(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_maximum_allowed(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of maximum_allowed set to the given value.
#Panics
If the given value is out of bounds for maximum_allowed.
Sourcepub fn with_maximum_allowed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_maximum_allowed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of maximum_allowed set to the given value.
#Errors
If the given value is out of bounds for maximum_allowed.
Sourcepub fn set_maximum_allowed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_maximum_allowed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of maximum_allowed to the given value.
#Panics
If the given value is out of bounds for maximum_allowed.
Sourcepub fn set_maximum_allowed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_maximum_allowed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of maximum_allowed to the given value.
#Errors
If the given value is out of bounds for maximum_allowed.
Sourcepub fn generic_all(&self) -> <bool as Specifier>::InOut
pub fn generic_all(&self) -> <bool as Specifier>::InOut
Returns the value of generic_all.
Sourcepub fn generic_all_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_all_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_all.
#Errors
If the returned value contains an invalid bit pattern for generic_all.
Sourcepub fn with_generic_all(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_all(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_all set to the given value.
#Panics
If the given value is out of bounds for generic_all.
Sourcepub fn with_generic_all_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_all_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_all set to the given value.
#Errors
If the given value is out of bounds for generic_all.
Sourcepub fn set_generic_all(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_all(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_all to the given value.
#Panics
If the given value is out of bounds for generic_all.
Sourcepub fn set_generic_all_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_all_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_all to the given value.
#Errors
If the given value is out of bounds for generic_all.
Sourcepub fn generic_execute(&self) -> <bool as Specifier>::InOut
pub fn generic_execute(&self) -> <bool as Specifier>::InOut
Returns the value of generic_execute.
Sourcepub fn generic_execute_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_execute_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_execute.
#Errors
If the returned value contains an invalid bit pattern for generic_execute.
Sourcepub fn with_generic_execute(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_execute(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_execute set to the given value.
#Panics
If the given value is out of bounds for generic_execute.
Sourcepub fn with_generic_execute_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_execute_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_execute set to the given value.
#Errors
If the given value is out of bounds for generic_execute.
Sourcepub fn set_generic_execute(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_execute(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_execute to the given value.
#Panics
If the given value is out of bounds for generic_execute.
Sourcepub fn set_generic_execute_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_execute_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_execute to the given value.
#Errors
If the given value is out of bounds for generic_execute.
Sourcepub fn generic_write(&self) -> <bool as Specifier>::InOut
pub fn generic_write(&self) -> <bool as Specifier>::InOut
Returns the value of generic_write.
Sourcepub fn generic_write_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_write.
#Errors
If the returned value contains an invalid bit pattern for generic_write.
Sourcepub fn with_generic_write(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_write(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_write set to the given value.
#Panics
If the given value is out of bounds for generic_write.
Sourcepub fn with_generic_write_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_write set to the given value.
#Errors
If the given value is out of bounds for generic_write.
Sourcepub fn set_generic_write(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_write(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_write to the given value.
#Panics
If the given value is out of bounds for generic_write.
Sourcepub fn set_generic_write_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_write to the given value.
#Errors
If the given value is out of bounds for generic_write.
Sourcepub fn generic_read(&self) -> <bool as Specifier>::InOut
pub fn generic_read(&self) -> <bool as Specifier>::InOut
Returns the value of generic_read.
Sourcepub fn generic_read_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn generic_read_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of generic_read.
#Errors
If the returned value contains an invalid bit pattern for generic_read.
Sourcepub fn with_generic_read(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_generic_read(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of generic_read set to the given value.
#Panics
If the given value is out of bounds for generic_read.
Sourcepub fn with_generic_read_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_generic_read_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of generic_read set to the given value.
#Errors
If the given value is out of bounds for generic_read.
Sourcepub fn set_generic_read(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_generic_read(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of generic_read to the given value.
#Panics
If the given value is out of bounds for generic_read.
Sourcepub fn set_generic_read_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_generic_read_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of generic_read to the given value.
#Errors
If the given value is out of bounds for generic_read.