pub struct FileAttributes { /* private fields */ }Expand description
MS-FSCC 2.6
Implementations
Sourceimpl FileAttributes
impl FileAttributes
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl FileAttributes
impl FileAttributes
Sourcepub fn readonly_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn readonly_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of readonly.
#Errors
If the returned value contains an invalid bit pattern for readonly.
Sourcepub fn with_readonly(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_readonly(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of readonly set to the given value.
#Panics
If the given value is out of bounds for readonly.
Sourcepub fn with_readonly_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_readonly_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of readonly set to the given value.
#Errors
If the given value is out of bounds for readonly.
Sourcepub fn set_readonly(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_readonly(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of readonly to the given value.
#Panics
If the given value is out of bounds for readonly.
Sourcepub fn set_readonly_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_readonly_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of readonly to the given value.
#Errors
If the given value is out of bounds for readonly.
Returns the value of hidden.
Returns the value of hidden.
#Errors
If the returned value contains an invalid bit pattern for hidden.
Returns a copy of the bitfield with the value of hidden set to the given value.
#Panics
If the given value is out of bounds for hidden.
Returns a copy of the bitfield with the value of hidden set to the given value.
#Errors
If the given value is out of bounds for hidden.
Sets the value of hidden to the given value.
#Panics
If the given value is out of bounds for hidden.
Sets the value of hidden to the given value.
#Errors
If the given value is out of bounds for hidden.
Sourcepub fn system_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn system_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of system.
#Errors
If the returned value contains an invalid bit pattern for system.
Sourcepub fn with_system(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_system(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of system set to the given value.
#Panics
If the given value is out of bounds for system.
Sourcepub fn with_system_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_system_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of system set to the given value.
#Errors
If the given value is out of bounds for system.
Sourcepub fn set_system(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_system(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of system to the given value.
#Panics
If the given value is out of bounds for system.
Sourcepub fn set_system_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_system_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of system to the given value.
#Errors
If the given value is out of bounds for system.
Sourcepub fn directory_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn directory_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of directory.
#Errors
If the returned value contains an invalid bit pattern for directory.
Sourcepub fn with_directory(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_directory(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of directory set to the given value.
#Panics
If the given value is out of bounds for directory.
Sourcepub fn with_directory_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_directory_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of directory set to the given value.
#Errors
If the given value is out of bounds for directory.
Sourcepub fn set_directory(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_directory(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of directory to the given value.
#Panics
If the given value is out of bounds for directory.
Sourcepub fn set_directory_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_directory_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of directory to the given value.
#Errors
If the given value is out of bounds for directory.
Sourcepub fn archive_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn archive_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of archive.
#Errors
If the returned value contains an invalid bit pattern for archive.
Sourcepub fn with_archive(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_archive(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of archive set to the given value.
#Panics
If the given value is out of bounds for archive.
Sourcepub fn with_archive_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_archive_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of archive set to the given value.
#Errors
If the given value is out of bounds for archive.
Sourcepub fn set_archive(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_archive(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of archive to the given value.
#Panics
If the given value is out of bounds for archive.
Sourcepub fn set_archive_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_archive_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of archive to the given value.
#Errors
If the given value is out of bounds for archive.
Sourcepub fn normal_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn normal_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of normal.
#Errors
If the returned value contains an invalid bit pattern for normal.
Sourcepub fn with_normal(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_normal(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of normal set to the given value.
#Panics
If the given value is out of bounds for normal.
Sourcepub fn with_normal_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_normal_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of normal set to the given value.
#Errors
If the given value is out of bounds for normal.
Sourcepub fn set_normal(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_normal(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of normal to the given value.
#Panics
If the given value is out of bounds for normal.
Sourcepub fn set_normal_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_normal_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of normal to the given value.
#Errors
If the given value is out of bounds for normal.
Sourcepub fn temporary_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn temporary_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of temporary.
#Errors
If the returned value contains an invalid bit pattern for temporary.
Sourcepub fn with_temporary(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_temporary(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of temporary set to the given value.
#Panics
If the given value is out of bounds for temporary.
Sourcepub fn with_temporary_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_temporary_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of temporary set to the given value.
#Errors
If the given value is out of bounds for temporary.
Sourcepub fn set_temporary(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_temporary(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of temporary to the given value.
#Panics
If the given value is out of bounds for temporary.
Sourcepub fn set_temporary_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_temporary_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of temporary to the given value.
#Errors
If the given value is out of bounds for temporary.
Sourcepub fn sparse_file(&self) -> <bool as Specifier>::InOut
pub fn sparse_file(&self) -> <bool as Specifier>::InOut
Returns the value of sparse_file.
Sourcepub fn sparse_file_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sparse_file_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sparse_file.
#Errors
If the returned value contains an invalid bit pattern for sparse_file.
Sourcepub fn with_sparse_file(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_sparse_file(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of sparse_file set to the given value.
#Panics
If the given value is out of bounds for sparse_file.
Sourcepub fn with_sparse_file_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sparse_file_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sparse_file set to the given value.
#Errors
If the given value is out of bounds for sparse_file.
Sourcepub fn set_sparse_file(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sparse_file(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sparse_file to the given value.
#Panics
If the given value is out of bounds for sparse_file.
Sourcepub fn set_sparse_file_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sparse_file_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sparse_file to the given value.
#Errors
If the given value is out of bounds for sparse_file.
Sourcepub fn reparse_point(&self) -> <bool as Specifier>::InOut
pub fn reparse_point(&self) -> <bool as Specifier>::InOut
Returns the value of reparse_point.
Sourcepub fn reparse_point_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn reparse_point_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of reparse_point.
#Errors
If the returned value contains an invalid bit pattern for reparse_point.
Sourcepub fn with_reparse_point(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_reparse_point(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of reparse_point set to the given value.
#Panics
If the given value is out of bounds for reparse_point.
Sourcepub fn with_reparse_point_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_reparse_point_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of reparse_point set to the given value.
#Errors
If the given value is out of bounds for reparse_point.
Sourcepub fn set_reparse_point(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_reparse_point(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of reparse_point to the given value.
#Panics
If the given value is out of bounds for reparse_point.
Sourcepub fn set_reparse_point_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_reparse_point_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of reparse_point to the given value.
#Errors
If the given value is out of bounds for reparse_point.
Sourcepub fn compressed(&self) -> <bool as Specifier>::InOut
pub fn compressed(&self) -> <bool as Specifier>::InOut
Returns the value of compressed.
Sourcepub fn compressed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn compressed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of compressed.
#Errors
If the returned value contains an invalid bit pattern for compressed.
Sourcepub fn with_compressed(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_compressed(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of compressed set to the given value.
#Panics
If the given value is out of bounds for compressed.
Sourcepub fn with_compressed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_compressed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of compressed set to the given value.
#Errors
If the given value is out of bounds for compressed.
Sourcepub fn set_compressed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_compressed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of compressed to the given value.
#Panics
If the given value is out of bounds for compressed.
Sourcepub fn set_compressed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_compressed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of compressed to the given value.
#Errors
If the given value is out of bounds for compressed.
Sourcepub fn offline_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn offline_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of offline.
#Errors
If the returned value contains an invalid bit pattern for offline.
Sourcepub fn with_offline(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_offline(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of offline set to the given value.
#Panics
If the given value is out of bounds for offline.
Sourcepub fn with_offline_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_offline_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of offline set to the given value.
#Errors
If the given value is out of bounds for offline.
Sourcepub fn set_offline(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_offline(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of offline to the given value.
#Panics
If the given value is out of bounds for offline.
Sourcepub fn set_offline_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_offline_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of offline to the given value.
#Errors
If the given value is out of bounds for offline.
Sourcepub fn not_content_indexed(&self) -> <bool as Specifier>::InOut
pub fn not_content_indexed(&self) -> <bool as Specifier>::InOut
Returns the value of not_content_indexed.
Sourcepub fn not_content_indexed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn not_content_indexed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of not_content_indexed.
#Errors
If the returned value contains an invalid bit pattern for not_content_indexed.
Sourcepub fn with_not_content_indexed(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_not_content_indexed( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of not_content_indexed set to the given value.
#Panics
If the given value is out of bounds for not_content_indexed.
Sourcepub fn with_not_content_indexed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_not_content_indexed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of not_content_indexed set to the given value.
#Errors
If the given value is out of bounds for not_content_indexed.
Sourcepub fn set_not_content_indexed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_not_content_indexed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of not_content_indexed to the given value.
#Panics
If the given value is out of bounds for not_content_indexed.
Sourcepub fn set_not_content_indexed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_not_content_indexed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of not_content_indexed to the given value.
#Errors
If the given value is out of bounds for not_content_indexed.
Sourcepub fn encrypted_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn encrypted_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of encrypted.
#Errors
If the returned value contains an invalid bit pattern for encrypted.
Sourcepub fn with_encrypted(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_encrypted(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of encrypted set to the given value.
#Panics
If the given value is out of bounds for encrypted.
Sourcepub fn with_encrypted_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_encrypted_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of encrypted set to the given value.
#Errors
If the given value is out of bounds for encrypted.
Sourcepub fn set_encrypted(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_encrypted(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of encrypted to the given value.
#Panics
If the given value is out of bounds for encrypted.
Sourcepub fn set_encrypted_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_encrypted_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of encrypted to the given value.
#Errors
If the given value is out of bounds for encrypted.
Sourcepub fn integrity_stream(&self) -> <bool as Specifier>::InOut
pub fn integrity_stream(&self) -> <bool as Specifier>::InOut
Returns the value of integrity_stream.
Sourcepub fn integrity_stream_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn integrity_stream_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of integrity_stream.
#Errors
If the returned value contains an invalid bit pattern for integrity_stream.
Sourcepub fn with_integrity_stream(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_integrity_stream(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of integrity_stream set to the given value.
#Panics
If the given value is out of bounds for integrity_stream.
Sourcepub fn with_integrity_stream_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_integrity_stream_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of integrity_stream set to the given value.
#Errors
If the given value is out of bounds for integrity_stream.
Sourcepub fn set_integrity_stream(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_integrity_stream(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of integrity_stream to the given value.
#Panics
If the given value is out of bounds for integrity_stream.
Sourcepub fn set_integrity_stream_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_integrity_stream_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of integrity_stream to the given value.
#Errors
If the given value is out of bounds for integrity_stream.
Sourcepub fn no_scrub_data(&self) -> <bool as Specifier>::InOut
pub fn no_scrub_data(&self) -> <bool as Specifier>::InOut
Returns the value of no_scrub_data.
Sourcepub fn no_scrub_data_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn no_scrub_data_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of no_scrub_data.
#Errors
If the returned value contains an invalid bit pattern for no_scrub_data.
Sourcepub fn with_no_scrub_data(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_no_scrub_data(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of no_scrub_data set to the given value.
#Panics
If the given value is out of bounds for no_scrub_data.
Sourcepub fn with_no_scrub_data_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_no_scrub_data_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of no_scrub_data set to the given value.
#Errors
If the given value is out of bounds for no_scrub_data.
Sourcepub fn set_no_scrub_data(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_no_scrub_data(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of no_scrub_data to the given value.
#Panics
If the given value is out of bounds for no_scrub_data.
Sourcepub fn set_no_scrub_data_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_no_scrub_data_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of no_scrub_data to the given value.
#Errors
If the given value is out of bounds for no_scrub_data.
Sourcepub fn recall_on_open(&self) -> <bool as Specifier>::InOut
pub fn recall_on_open(&self) -> <bool as Specifier>::InOut
Returns the value of recall_on_open.
Sourcepub fn recall_on_open_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn recall_on_open_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of recall_on_open.
#Errors
If the returned value contains an invalid bit pattern for recall_on_open.
Sourcepub fn with_recall_on_open(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_recall_on_open(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of recall_on_open set to the given value.
#Panics
If the given value is out of bounds for recall_on_open.
Sourcepub fn with_recall_on_open_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_recall_on_open_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of recall_on_open set to the given value.
#Errors
If the given value is out of bounds for recall_on_open.
Sourcepub fn set_recall_on_open(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_recall_on_open(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of recall_on_open to the given value.
#Panics
If the given value is out of bounds for recall_on_open.
Sourcepub fn set_recall_on_open_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_recall_on_open_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of recall_on_open to the given value.
#Errors
If the given value is out of bounds for recall_on_open.
Sourcepub fn pinned_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn pinned_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of pinned.
#Errors
If the returned value contains an invalid bit pattern for pinned.
Sourcepub fn with_pinned(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_pinned(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of pinned set to the given value.
#Panics
If the given value is out of bounds for pinned.
Sourcepub fn with_pinned_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_pinned_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of pinned set to the given value.
#Errors
If the given value is out of bounds for pinned.
Sourcepub fn set_pinned(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_pinned(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of pinned to the given value.
#Panics
If the given value is out of bounds for pinned.
Sourcepub fn set_pinned_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_pinned_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of pinned to the given value.
#Errors
If the given value is out of bounds for pinned.
Sourcepub fn unpinned_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn unpinned_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of unpinned.
#Errors
If the returned value contains an invalid bit pattern for unpinned.
Sourcepub fn with_unpinned(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_unpinned(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of unpinned set to the given value.
#Panics
If the given value is out of bounds for unpinned.
Sourcepub fn with_unpinned_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_unpinned_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of unpinned set to the given value.
#Errors
If the given value is out of bounds for unpinned.
Sourcepub fn set_unpinned(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_unpinned(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of unpinned to the given value.
#Panics
If the given value is out of bounds for unpinned.
Sourcepub fn set_unpinned_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_unpinned_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of unpinned to the given value.
#Errors
If the given value is out of bounds for unpinned.
Sourcepub fn recall_on_data_access(&self) -> <bool as Specifier>::InOut
pub fn recall_on_data_access(&self) -> <bool as Specifier>::InOut
Returns the value of recall_on_data_access.
Sourcepub fn recall_on_data_access_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn recall_on_data_access_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of recall_on_data_access.
#Errors
If the returned value contains an invalid bit pattern for recall_on_data_access.
Sourcepub fn with_recall_on_data_access(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_recall_on_data_access( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of recall_on_data_access set to the given value.
#Panics
If the given value is out of bounds for recall_on_data_access.
Sourcepub fn with_recall_on_data_access_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_recall_on_data_access_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of recall_on_data_access set to the given value.
#Errors
If the given value is out of bounds for recall_on_data_access.
Sourcepub fn set_recall_on_data_access(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_recall_on_data_access(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of recall_on_data_access to the given value.
#Panics
If the given value is out of bounds for recall_on_data_access.
Sourcepub fn set_recall_on_data_access_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_recall_on_data_access_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of recall_on_data_access to the given value.
#Errors
If the given value is out of bounds for recall_on_data_access.