pub struct FileEndOfFileInformation {
pub end_of_file: u64,
}Expand description
Set end-of-file information for a file.
Fields
end_of_file: u64The absolute new end of file position as a byte offset from the start of the file. Specifies the offset from the beginning of the file of the byte following the last byte in the file. That is, it is the offset from the beginning of the file at which new bytes appended to the file will be written. The value of this field MUST be greater than or equal to 0.