pub struct FileFsAttributeInformation {
pub attributes: FileSystemAttributes,
pub maximum_component_name_length: u32,
pub file_system_name: SizedWideString,
}Expand description
Query attribute information for a file system.
Fields
attributes: FileSystemAttributesContains a bitmask of flags that specify attributes of the specified file system as a combination of the following flags. The value of this field MUST be a bitwise OR of zero or more of the following with the exception that FILE_FILE_COMPRESSION and FILE_VOLUME_IS_COMPRESSED cannot both be set. Any flag values not explicitly mentioned here can be set to any value, and MUST be ignored.
maximum_component_name_length: u32The maximum file name component length, in characters, supported by the specified file system. The value of this field MUST be greater than zero and MUST be no more than 255.
file_system_name: SizedWideStringthe name of the file system. This field is not null-terminated and MUST be handled as a sequence of FileSystemNameLength bytes. This field is intended to be informative only. A client SHOULD NOT infer file system type specific behavior from this field.