pub struct FileFsControlInformation {
pub free_space_start_filtering: u64,
pub free_space_threshold: u64,
pub free_space_stop_filtering: u64,
pub default_quota_threshold: u64,
pub default_quota_limit: u64,
pub file_system_control_flags: FileSystemControlFlags,
}Expand description
Query or Set quota and content indexing control information for a file system volume.
Setting quota information requires the caller to have permission to open a volume handle or a handle to the quota index file for write access.
Fields
free_space_start_filtering: u64The minimum amount of free disk space, in bytes, that is required for the operating system’s content indexing service to begin document filtering. This value SHOULD be set to 0 and MUST be ignored.
free_space_threshold: u64The minimum amount of free disk space, in bytes, that is required for the indexing service to continue to filter documents and merge word lists. This value SHOULD be set to 0 and MUST be ignored.
free_space_stop_filtering: u64The minimum amount of free disk space, in bytes, that is required for the content indexing service to continue filtering. This value SHOULD be set to 0, and MUST be ignored.
default_quota_threshold: u64The default per-user disk quota warning threshold, in bytes, for the volume. A value of u64::MAX specifies that no default quota warning threshold per user is set.
default_quota_limit: u64The default per-user disk quota limit, in bytes, for the volume. A value of u64::MAX specifies that no default quota limit per user is set.
file_system_control_flags: FileSystemControlFlagsContains a bitmask of flags that control quota enforcement and logging of user-related quota events on the volume.