pub struct FileFsObjectIdInformation {
pub object_id: Guid,
pub extended_info: [u8; 48],
}Expand description
Query or Set the object ID for a file system data element. The operation MUST fail if the file system does not support object IDs.
Fields
object_id: GuidIdentifies the file system volume on the disk. This value is not required to be unique on the system.
extended_info: [u8; 48]A 48-byte value containing extended information on the file system volume. If no extended information has been written for this file system volume, the server MUST return 48 bytes of 0x00 in this field.