pub struct FileFsSizeInformation {
pub total_allocation_units: u64,
pub available_allocation_units: u64,
pub sectors_per_allocation_unit: u32,
pub bytes_per_sector: u32,
}Expand description
Query sector size information for a file system volume.
Fields
total_allocation_units: u64The total number of allocation units on the volume that are available to the user associated with the calling thread. This value MUST be greater than or equal to 0.
available_allocation_units: u64The total number of free allocation units on the volume that are available to the user associated with the calling thread. This value MUST be greater than or equal to 0.
sectors_per_allocation_unit: u32The number of sectors in each allocation unit.
bytes_per_sector: u32The number of bytes in each sector.