pub struct FileFsVolumeInformation {
pub volume_creation_time: FileTime,
pub volume_serial_number: u32,
pub supports_objects: Boolean,
pub volume_label: SizedWideString,
}Expand description
Query information on a volume on which a file system is mounted.
Fields
volume_creation_time: FileTimeThe time when the volume was created.
volume_serial_number: u32C contains the serial number of the volume. The serial number is an opaque value generated by the file system at format time, and is not necessarily related to any hardware serial number for the device on which the file system is located. No specific format or content of this field is required for protocol interoperation. This value is not required to be unique.
supports_objects: BooleanSet to TRUE if the file system supports object-oriented file system objects; set to FALSE otherwise.
volume_label: SizedWideStringThe content of this field can be a null-terminated string or can be a string padded with the space character to be VolumeLabelLength bytes long.