pub struct FilePipeRemoteInformation {
pub collect_data_time: FileTime,
pub maximum_collection_count: u32,
}Expand description
Query information that is associated with the remote end of a named pipe.
Fields
collect_data_time: FileTimeThe time at which the data is collected.
maximum_collection_count: u32The maximum size, in bytes, of data that will be collected before transmission to the remote end of the named pipe.