pub struct FileSystemAttributes { /* private fields */ }Expand description
File system attributes.
Used in FileFsAttributeInformation
Implementations
Sourceimpl FileSystemAttributes
impl FileSystemAttributes
Sourcepub const fn into_bytes(self) -> [u8; 4]
pub const fn into_bytes(self) -> [u8; 4]
Sourcepub const fn from_bytes(bytes: [u8; 4]) -> Self
pub const fn from_bytes(bytes: [u8; 4]) -> Self
Converts the given bytes directly into the bitfield struct.
Sourceimpl FileSystemAttributes
impl FileSystemAttributes
Sourcepub fn case_sensitive_search(&self) -> <bool as Specifier>::InOut
pub fn case_sensitive_search(&self) -> <bool as Specifier>::InOut
Returns the value of case_sensitive_search. The file system supports case-sensitive file names when looking up (searching for) file names in a directory.
Sourcepub fn case_sensitive_search_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn case_sensitive_search_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of case_sensitive_search.
#Errors
If the returned value contains an invalid bit pattern for case_sensitive_search. The file system supports case-sensitive file names when looking up (searching for) file names in a directory.
Sourcepub fn with_case_sensitive_search(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_case_sensitive_search( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of case_sensitive_search set to the given value.
#Panics
If the given value is out of bounds for case_sensitive_search. The file system supports case-sensitive file names when looking up (searching for) file names in a directory.
Sourcepub fn with_case_sensitive_search_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_case_sensitive_search_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of case_sensitive_search set to the given value.
#Errors
If the given value is out of bounds for case_sensitive_search. The file system supports case-sensitive file names when looking up (searching for) file names in a directory.
Sourcepub fn set_case_sensitive_search(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_case_sensitive_search(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of case_sensitive_search to the given value.
#Panics
If the given value is out of bounds for case_sensitive_search. The file system supports case-sensitive file names when looking up (searching for) file names in a directory.
Sourcepub fn set_case_sensitive_search_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_case_sensitive_search_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of case_sensitive_search to the given value.
#Errors
If the given value is out of bounds for case_sensitive_search. The file system supports case-sensitive file names when looking up (searching for) file names in a directory.
Sourcepub fn case_preserved_names(&self) -> <bool as Specifier>::InOut
pub fn case_preserved_names(&self) -> <bool as Specifier>::InOut
Returns the value of case_preserved_names. The file system preserves the case of file names when it places a name on disk.
Sourcepub fn case_preserved_names_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn case_preserved_names_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of case_preserved_names.
#Errors
If the returned value contains an invalid bit pattern for case_preserved_names. The file system preserves the case of file names when it places a name on disk.
Sourcepub fn with_case_preserved_names(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_case_preserved_names( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of case_preserved_names set to the given value.
#Panics
If the given value is out of bounds for case_preserved_names. The file system preserves the case of file names when it places a name on disk.
Sourcepub fn with_case_preserved_names_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_case_preserved_names_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of case_preserved_names set to the given value.
#Errors
If the given value is out of bounds for case_preserved_names. The file system preserves the case of file names when it places a name on disk.
Sourcepub fn set_case_preserved_names(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_case_preserved_names(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of case_preserved_names to the given value.
#Panics
If the given value is out of bounds for case_preserved_names. The file system preserves the case of file names when it places a name on disk.
Sourcepub fn set_case_preserved_names_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_case_preserved_names_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of case_preserved_names to the given value.
#Errors
If the given value is out of bounds for case_preserved_names. The file system preserves the case of file names when it places a name on disk.
Sourcepub fn unicode_on_disk(&self) -> <bool as Specifier>::InOut
pub fn unicode_on_disk(&self) -> <bool as Specifier>::InOut
Returns the value of unicode_on_disk. The file system supports Unicode in file and directory names. This flag applies only to file and directory names; the file system neither restricts nor interprets the bytes of data within a file.
Sourcepub fn unicode_on_disk_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn unicode_on_disk_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of unicode_on_disk.
#Errors
If the returned value contains an invalid bit pattern for unicode_on_disk. The file system supports Unicode in file and directory names. This flag applies only to file and directory names; the file system neither restricts nor interprets the bytes of data within a file.
Sourcepub fn with_unicode_on_disk(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_unicode_on_disk(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of unicode_on_disk set to the given value.
#Panics
If the given value is out of bounds for unicode_on_disk. The file system supports Unicode in file and directory names. This flag applies only to file and directory names; the file system neither restricts nor interprets the bytes of data within a file.
Sourcepub fn with_unicode_on_disk_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_unicode_on_disk_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of unicode_on_disk set to the given value.
#Errors
If the given value is out of bounds for unicode_on_disk. The file system supports Unicode in file and directory names. This flag applies only to file and directory names; the file system neither restricts nor interprets the bytes of data within a file.
Sourcepub fn set_unicode_on_disk(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_unicode_on_disk(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of unicode_on_disk to the given value.
#Panics
If the given value is out of bounds for unicode_on_disk. The file system supports Unicode in file and directory names. This flag applies only to file and directory names; the file system neither restricts nor interprets the bytes of data within a file.
Sourcepub fn set_unicode_on_disk_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_unicode_on_disk_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of unicode_on_disk to the given value.
#Errors
If the given value is out of bounds for unicode_on_disk. The file system supports Unicode in file and directory names. This flag applies only to file and directory names; the file system neither restricts nor interprets the bytes of data within a file.
Sourcepub fn persistent_acls(&self) -> <bool as Specifier>::InOut
pub fn persistent_acls(&self) -> <bool as Specifier>::InOut
Returns the value of persistent_acls. The file system preserves and enforces access control lists (ACLs).
Sourcepub fn persistent_acls_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn persistent_acls_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of persistent_acls.
#Errors
If the returned value contains an invalid bit pattern for persistent_acls. The file system preserves and enforces access control lists (ACLs).
Sourcepub fn with_persistent_acls(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_persistent_acls(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of persistent_acls set to the given value.
#Panics
If the given value is out of bounds for persistent_acls. The file system preserves and enforces access control lists (ACLs).
Sourcepub fn with_persistent_acls_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_persistent_acls_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of persistent_acls set to the given value.
#Errors
If the given value is out of bounds for persistent_acls. The file system preserves and enforces access control lists (ACLs).
Sourcepub fn set_persistent_acls(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_persistent_acls(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of persistent_acls to the given value.
#Panics
If the given value is out of bounds for persistent_acls. The file system preserves and enforces access control lists (ACLs).
Sourcepub fn set_persistent_acls_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_persistent_acls_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of persistent_acls to the given value.
#Errors
If the given value is out of bounds for persistent_acls. The file system preserves and enforces access control lists (ACLs).
Sourcepub fn file_compression(&self) -> <bool as Specifier>::InOut
pub fn file_compression(&self) -> <bool as Specifier>::InOut
Returns the value of file_compression.
The file volume supports file-based compression. This flag is incompatible with the volume_is_compressed flag.
Sourcepub fn file_compression_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn file_compression_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of file_compression.
#Errors
If the returned value contains an invalid bit pattern for file_compression.
The file volume supports file-based compression. This flag is incompatible with the volume_is_compressed flag.
Sourcepub fn with_file_compression(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_file_compression(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of file_compression set to the given value.
#Panics
If the given value is out of bounds for file_compression.
The file volume supports file-based compression. This flag is incompatible with the volume_is_compressed flag.
Sourcepub fn with_file_compression_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_file_compression_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of file_compression set to the given value.
#Errors
If the given value is out of bounds for file_compression.
The file volume supports file-based compression. This flag is incompatible with the volume_is_compressed flag.
Sourcepub fn set_file_compression(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_file_compression(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of file_compression to the given value.
#Panics
If the given value is out of bounds for file_compression.
The file volume supports file-based compression. This flag is incompatible with the volume_is_compressed flag.
Sourcepub fn set_file_compression_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_file_compression_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of file_compression to the given value.
#Errors
If the given value is out of bounds for file_compression.
The file volume supports file-based compression. This flag is incompatible with the volume_is_compressed flag.
Sourcepub fn volume_quotas(&self) -> <bool as Specifier>::InOut
pub fn volume_quotas(&self) -> <bool as Specifier>::InOut
Returns the value of volume_quotas. The file system supports per-user quotas.
Sourcepub fn volume_quotas_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn volume_quotas_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of volume_quotas.
#Errors
If the returned value contains an invalid bit pattern for volume_quotas. The file system supports per-user quotas.
Sourcepub fn with_volume_quotas(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_volume_quotas(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of volume_quotas set to the given value.
#Panics
If the given value is out of bounds for volume_quotas. The file system supports per-user quotas.
Sourcepub fn with_volume_quotas_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_volume_quotas_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of volume_quotas set to the given value.
#Errors
If the given value is out of bounds for volume_quotas. The file system supports per-user quotas.
Sourcepub fn set_volume_quotas(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_volume_quotas(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of volume_quotas to the given value.
#Panics
If the given value is out of bounds for volume_quotas. The file system supports per-user quotas.
Sourcepub fn set_volume_quotas_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_volume_quotas_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of volume_quotas to the given value.
#Errors
If the given value is out of bounds for volume_quotas. The file system supports per-user quotas.
Sourcepub fn supports_sparse_files(&self) -> <bool as Specifier>::InOut
pub fn supports_sparse_files(&self) -> <bool as Specifier>::InOut
Returns the value of supports_sparse_files. The file system supports sparse files.
Sourcepub fn supports_sparse_files_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_sparse_files_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_sparse_files.
#Errors
If the returned value contains an invalid bit pattern for supports_sparse_files. The file system supports sparse files.
Sourcepub fn with_supports_sparse_files(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_sparse_files( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_sparse_files set to the given value.
#Panics
If the given value is out of bounds for supports_sparse_files. The file system supports sparse files.
Sourcepub fn with_supports_sparse_files_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_sparse_files_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_sparse_files set to the given value.
#Errors
If the given value is out of bounds for supports_sparse_files. The file system supports sparse files.
Sourcepub fn set_supports_sparse_files(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_supports_sparse_files(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of supports_sparse_files to the given value.
#Panics
If the given value is out of bounds for supports_sparse_files. The file system supports sparse files.
Sourcepub fn set_supports_sparse_files_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_sparse_files_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_sparse_files to the given value.
#Errors
If the given value is out of bounds for supports_sparse_files. The file system supports sparse files.
Sourcepub fn supports_reparse_points(&self) -> <bool as Specifier>::InOut
pub fn supports_reparse_points(&self) -> <bool as Specifier>::InOut
Returns the value of supports_reparse_points. The file system supports reparse points.
Sourcepub fn supports_reparse_points_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_reparse_points_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_reparse_points.
#Errors
If the returned value contains an invalid bit pattern for supports_reparse_points. The file system supports reparse points.
Sourcepub fn with_supports_reparse_points(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_reparse_points( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_reparse_points set to the given value.
#Panics
If the given value is out of bounds for supports_reparse_points. The file system supports reparse points.
Sourcepub fn with_supports_reparse_points_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_reparse_points_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_reparse_points set to the given value.
#Errors
If the given value is out of bounds for supports_reparse_points. The file system supports reparse points.
Sourcepub fn set_supports_reparse_points(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_supports_reparse_points( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of supports_reparse_points to the given value.
#Panics
If the given value is out of bounds for supports_reparse_points. The file system supports reparse points.
Sourcepub fn set_supports_reparse_points_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_reparse_points_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_reparse_points to the given value.
#Errors
If the given value is out of bounds for supports_reparse_points. The file system supports reparse points.
Sourcepub fn supports_remote_storage(&self) -> <bool as Specifier>::InOut
pub fn supports_remote_storage(&self) -> <bool as Specifier>::InOut
Returns the value of supports_remote_storage. The file system supports remote storage.
Sourcepub fn supports_remote_storage_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_remote_storage_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_remote_storage.
#Errors
If the returned value contains an invalid bit pattern for supports_remote_storage. The file system supports remote storage.
Sourcepub fn with_supports_remote_storage(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_remote_storage( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_remote_storage set to the given value.
#Panics
If the given value is out of bounds for supports_remote_storage. The file system supports remote storage.
Sourcepub fn with_supports_remote_storage_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_remote_storage_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_remote_storage set to the given value.
#Errors
If the given value is out of bounds for supports_remote_storage. The file system supports remote storage.
Sourcepub fn set_supports_remote_storage(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_supports_remote_storage( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of supports_remote_storage to the given value.
#Panics
If the given value is out of bounds for supports_remote_storage. The file system supports remote storage.
Sourcepub fn set_supports_remote_storage_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_remote_storage_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_remote_storage to the given value.
#Errors
If the given value is out of bounds for supports_remote_storage. The file system supports remote storage.
Sourcepub fn volume_is_compressed(&self) -> <bool as Specifier>::InOut
pub fn volume_is_compressed(&self) -> <bool as Specifier>::InOut
Returns the value of volume_is_compressed.
The specified volume is a compressed volume. This flag is incompatible with the file_compression flag.
Sourcepub fn volume_is_compressed_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn volume_is_compressed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of volume_is_compressed.
#Errors
If the returned value contains an invalid bit pattern for volume_is_compressed.
The specified volume is a compressed volume. This flag is incompatible with the file_compression flag.
Sourcepub fn with_volume_is_compressed(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_volume_is_compressed( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of volume_is_compressed set to the given value.
#Panics
If the given value is out of bounds for volume_is_compressed.
The specified volume is a compressed volume. This flag is incompatible with the file_compression flag.
Sourcepub fn with_volume_is_compressed_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_volume_is_compressed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of volume_is_compressed set to the given value.
#Errors
If the given value is out of bounds for volume_is_compressed.
The specified volume is a compressed volume. This flag is incompatible with the file_compression flag.
Sourcepub fn set_volume_is_compressed(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_volume_is_compressed(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of volume_is_compressed to the given value.
#Panics
If the given value is out of bounds for volume_is_compressed.
The specified volume is a compressed volume. This flag is incompatible with the file_compression flag.
Sourcepub fn set_volume_is_compressed_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_volume_is_compressed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of volume_is_compressed to the given value.
#Errors
If the given value is out of bounds for volume_is_compressed.
The specified volume is a compressed volume. This flag is incompatible with the file_compression flag.
Sourcepub fn supports_object_ids(&self) -> <bool as Specifier>::InOut
pub fn supports_object_ids(&self) -> <bool as Specifier>::InOut
Returns the value of supports_object_ids. The file system supports object identifiers.
Sourcepub fn supports_object_ids_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_object_ids_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_object_ids.
#Errors
If the returned value contains an invalid bit pattern for supports_object_ids. The file system supports object identifiers.
Sourcepub fn with_supports_object_ids(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_object_ids( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_object_ids set to the given value.
#Panics
If the given value is out of bounds for supports_object_ids. The file system supports object identifiers.
Sourcepub fn with_supports_object_ids_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_object_ids_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_object_ids set to the given value.
#Errors
If the given value is out of bounds for supports_object_ids. The file system supports object identifiers.
Sourcepub fn set_supports_object_ids(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_supports_object_ids(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of supports_object_ids to the given value.
#Panics
If the given value is out of bounds for supports_object_ids. The file system supports object identifiers.
Sourcepub fn set_supports_object_ids_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_object_ids_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_object_ids to the given value.
#Errors
If the given value is out of bounds for supports_object_ids. The file system supports object identifiers.
Sourcepub fn supports_encryption(&self) -> <bool as Specifier>::InOut
pub fn supports_encryption(&self) -> <bool as Specifier>::InOut
Returns the value of supports_encryption. The file system supports the Encrypted File System (EFS).
Sourcepub fn supports_encryption_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_encryption_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_encryption.
#Errors
If the returned value contains an invalid bit pattern for supports_encryption. The file system supports the Encrypted File System (EFS).
Sourcepub fn with_supports_encryption(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_encryption( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_encryption set to the given value.
#Panics
If the given value is out of bounds for supports_encryption. The file system supports the Encrypted File System (EFS).
Sourcepub fn with_supports_encryption_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_encryption_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_encryption set to the given value.
#Errors
If the given value is out of bounds for supports_encryption. The file system supports the Encrypted File System (EFS).
Sourcepub fn set_supports_encryption(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_supports_encryption(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of supports_encryption to the given value.
#Panics
If the given value is out of bounds for supports_encryption. The file system supports the Encrypted File System (EFS).
Sourcepub fn set_supports_encryption_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_encryption_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_encryption to the given value.
#Errors
If the given value is out of bounds for supports_encryption. The file system supports the Encrypted File System (EFS).
Sourcepub fn named_streams(&self) -> <bool as Specifier>::InOut
pub fn named_streams(&self) -> <bool as Specifier>::InOut
Returns the value of named_streams. The file system supports named streams.
Sourcepub fn named_streams_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn named_streams_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of named_streams.
#Errors
If the returned value contains an invalid bit pattern for named_streams. The file system supports named streams.
Sourcepub fn with_named_streams(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_named_streams(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of named_streams set to the given value.
#Panics
If the given value is out of bounds for named_streams. The file system supports named streams.
Sourcepub fn with_named_streams_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_named_streams_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of named_streams set to the given value.
#Errors
If the given value is out of bounds for named_streams. The file system supports named streams.
Sourcepub fn set_named_streams(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_named_streams(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of named_streams to the given value.
#Panics
If the given value is out of bounds for named_streams. The file system supports named streams.
Sourcepub fn set_named_streams_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_named_streams_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of named_streams to the given value.
#Errors
If the given value is out of bounds for named_streams. The file system supports named streams.
Sourcepub fn read_only_volume(&self) -> <bool as Specifier>::InOut
pub fn read_only_volume(&self) -> <bool as Specifier>::InOut
Returns the value of read_only_volume. If set, the volume has been mounted in read-only mode.
Sourcepub fn read_only_volume_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn read_only_volume_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of read_only_volume.
#Errors
If the returned value contains an invalid bit pattern for read_only_volume. If set, the volume has been mounted in read-only mode.
Sourcepub fn with_read_only_volume(self, new_val: <bool as Specifier>::InOut) -> Self
pub fn with_read_only_volume(self, new_val: <bool as Specifier>::InOut) -> Self
Returns a copy of the bitfield with the value of read_only_volume set to the given value.
#Panics
If the given value is out of bounds for read_only_volume. If set, the volume has been mounted in read-only mode.
Sourcepub fn with_read_only_volume_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_read_only_volume_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of read_only_volume set to the given value.
#Errors
If the given value is out of bounds for read_only_volume. If set, the volume has been mounted in read-only mode.
Sourcepub fn set_read_only_volume(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_read_only_volume(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of read_only_volume to the given value.
#Panics
If the given value is out of bounds for read_only_volume. If set, the volume has been mounted in read-only mode.
Sourcepub fn set_read_only_volume_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_read_only_volume_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of read_only_volume to the given value.
#Errors
If the given value is out of bounds for read_only_volume. If set, the volume has been mounted in read-only mode.
Sourcepub fn sequential_write_once(&self) -> <bool as Specifier>::InOut
pub fn sequential_write_once(&self) -> <bool as Specifier>::InOut
Returns the value of sequential_write_once. The underlying volume is write once.
Sourcepub fn sequential_write_once_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn sequential_write_once_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of sequential_write_once.
#Errors
If the returned value contains an invalid bit pattern for sequential_write_once. The underlying volume is write once.
Sourcepub fn with_sequential_write_once(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_sequential_write_once( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of sequential_write_once set to the given value.
#Panics
If the given value is out of bounds for sequential_write_once. The underlying volume is write once.
Sourcepub fn with_sequential_write_once_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_sequential_write_once_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of sequential_write_once set to the given value.
#Errors
If the given value is out of bounds for sequential_write_once. The underlying volume is write once.
Sourcepub fn set_sequential_write_once(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_sequential_write_once(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of sequential_write_once to the given value.
#Panics
If the given value is out of bounds for sequential_write_once. The underlying volume is write once.
Sourcepub fn set_sequential_write_once_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_sequential_write_once_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of sequential_write_once to the given value.
#Errors
If the given value is out of bounds for sequential_write_once. The underlying volume is write once.
Sourcepub fn supports_transactions(&self) -> <bool as Specifier>::InOut
pub fn supports_transactions(&self) -> <bool as Specifier>::InOut
Returns the value of supports_transactions. The volume supports transactions.
Sourcepub fn supports_transactions_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_transactions_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_transactions.
#Errors
If the returned value contains an invalid bit pattern for supports_transactions. The volume supports transactions.
Sourcepub fn with_supports_transactions(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_transactions( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_transactions set to the given value.
#Panics
If the given value is out of bounds for supports_transactions. The volume supports transactions.
Sourcepub fn with_supports_transactions_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_transactions_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_transactions set to the given value.
#Errors
If the given value is out of bounds for supports_transactions. The volume supports transactions.
Sourcepub fn set_supports_transactions(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_supports_transactions(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of supports_transactions to the given value.
#Panics
If the given value is out of bounds for supports_transactions. The volume supports transactions.
Sourcepub fn set_supports_transactions_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_transactions_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_transactions to the given value.
#Errors
If the given value is out of bounds for supports_transactions. The volume supports transactions.
Sourcepub fn supports_hard_links(&self) -> <bool as Specifier>::InOut
pub fn supports_hard_links(&self) -> <bool as Specifier>::InOut
Returns the value of supports_hard_links. The file system supports hard linking files.
Sourcepub fn supports_hard_links_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_hard_links_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_hard_links.
#Errors
If the returned value contains an invalid bit pattern for supports_hard_links. The file system supports hard linking files.
Sourcepub fn with_supports_hard_links(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_hard_links( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_hard_links set to the given value.
#Panics
If the given value is out of bounds for supports_hard_links. The file system supports hard linking files.
Sourcepub fn with_supports_hard_links_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_hard_links_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_hard_links set to the given value.
#Errors
If the given value is out of bounds for supports_hard_links. The file system supports hard linking files.
Sourcepub fn set_supports_hard_links(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_supports_hard_links(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of supports_hard_links to the given value.
#Panics
If the given value is out of bounds for supports_hard_links. The file system supports hard linking files.
Sourcepub fn set_supports_hard_links_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_hard_links_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_hard_links to the given value.
#Errors
If the given value is out of bounds for supports_hard_links. The file system supports hard linking files.
Sourcepub fn supports_extended_attributes(&self) -> <bool as Specifier>::InOut
pub fn supports_extended_attributes(&self) -> <bool as Specifier>::InOut
Returns the value of supports_extended_attributes. The file system persistently stores Extended Attribute information per file.
Sourcepub fn supports_extended_attributes_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_extended_attributes_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_extended_attributes.
#Errors
If the returned value contains an invalid bit pattern for supports_extended_attributes. The file system persistently stores Extended Attribute information per file.
Sourcepub fn with_supports_extended_attributes(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_extended_attributes( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_extended_attributes set to the given value.
#Panics
If the given value is out of bounds for supports_extended_attributes. The file system persistently stores Extended Attribute information per file.
Sourcepub fn with_supports_extended_attributes_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_extended_attributes_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_extended_attributes set to the given value.
#Errors
If the given value is out of bounds for supports_extended_attributes. The file system persistently stores Extended Attribute information per file.
Sourcepub fn set_supports_extended_attributes(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_supports_extended_attributes( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of supports_extended_attributes to the given value.
#Panics
If the given value is out of bounds for supports_extended_attributes. The file system persistently stores Extended Attribute information per file.
Sourcepub fn set_supports_extended_attributes_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_extended_attributes_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_extended_attributes to the given value.
#Errors
If the given value is out of bounds for supports_extended_attributes. The file system persistently stores Extended Attribute information per file.
Sourcepub fn supports_open_by_file_id(&self) -> <bool as Specifier>::InOut
pub fn supports_open_by_file_id(&self) -> <bool as Specifier>::InOut
Returns the value of supports_open_by_file_id. The file system supports opening a file by FileID or ObjectID.
Sourcepub fn supports_open_by_file_id_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_open_by_file_id_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_open_by_file_id.
#Errors
If the returned value contains an invalid bit pattern for supports_open_by_file_id. The file system supports opening a file by FileID or ObjectID.
Sourcepub fn with_supports_open_by_file_id(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_open_by_file_id( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_open_by_file_id set to the given value.
#Panics
If the given value is out of bounds for supports_open_by_file_id. The file system supports opening a file by FileID or ObjectID.
Sourcepub fn with_supports_open_by_file_id_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_open_by_file_id_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_open_by_file_id set to the given value.
#Errors
If the given value is out of bounds for supports_open_by_file_id. The file system supports opening a file by FileID or ObjectID.
Sourcepub fn set_supports_open_by_file_id(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_supports_open_by_file_id( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of supports_open_by_file_id to the given value.
#Panics
If the given value is out of bounds for supports_open_by_file_id. The file system supports opening a file by FileID or ObjectID.
Sourcepub fn set_supports_open_by_file_id_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_open_by_file_id_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_open_by_file_id to the given value.
#Errors
If the given value is out of bounds for supports_open_by_file_id. The file system supports opening a file by FileID or ObjectID.
Sourcepub fn supports_usn_journal(&self) -> <bool as Specifier>::InOut
pub fn supports_usn_journal(&self) -> <bool as Specifier>::InOut
Returns the value of supports_usn_journal. The file system implements a USN change journal.
Sourcepub fn supports_usn_journal_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_usn_journal_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_usn_journal.
#Errors
If the returned value contains an invalid bit pattern for supports_usn_journal. The file system implements a USN change journal.
Sourcepub fn with_supports_usn_journal(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_usn_journal( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_usn_journal set to the given value.
#Panics
If the given value is out of bounds for supports_usn_journal. The file system implements a USN change journal.
Sourcepub fn with_supports_usn_journal_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_usn_journal_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_usn_journal set to the given value.
#Errors
If the given value is out of bounds for supports_usn_journal. The file system implements a USN change journal.
Sourcepub fn set_supports_usn_journal(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_supports_usn_journal(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of supports_usn_journal to the given value.
#Panics
If the given value is out of bounds for supports_usn_journal. The file system implements a USN change journal.
Sourcepub fn set_supports_usn_journal_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_usn_journal_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_usn_journal to the given value.
#Errors
If the given value is out of bounds for supports_usn_journal. The file system implements a USN change journal.
Sourcepub fn support_integrity_streams(&self) -> <bool as Specifier>::InOut
pub fn support_integrity_streams(&self) -> <bool as Specifier>::InOut
Returns the value of support_integrity_streams. The file system supports integrity streams.
Sourcepub fn support_integrity_streams_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn support_integrity_streams_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of support_integrity_streams.
#Errors
If the returned value contains an invalid bit pattern for support_integrity_streams. The file system supports integrity streams.
Sourcepub fn with_support_integrity_streams(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_support_integrity_streams( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of support_integrity_streams set to the given value.
#Panics
If the given value is out of bounds for support_integrity_streams. The file system supports integrity streams.
Sourcepub fn with_support_integrity_streams_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_support_integrity_streams_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of support_integrity_streams set to the given value.
#Errors
If the given value is out of bounds for support_integrity_streams. The file system supports integrity streams.
Sourcepub fn set_support_integrity_streams(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_support_integrity_streams( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of support_integrity_streams to the given value.
#Panics
If the given value is out of bounds for support_integrity_streams. The file system supports integrity streams.
Sourcepub fn set_support_integrity_streams_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_support_integrity_streams_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of support_integrity_streams to the given value.
#Errors
If the given value is out of bounds for support_integrity_streams. The file system supports integrity streams.
Sourcepub fn supports_block_refcounting(&self) -> <bool as Specifier>::InOut
pub fn supports_block_refcounting(&self) -> <bool as Specifier>::InOut
Returns the value of supports_block_refcounting.
The file system supports sharing logical clusters between files on the same volume. The file system reallocates on writes to shared clusters. Indicates that FSCTL_DUPLICATE_EXTENTS_TO_FILE is a supported operation.
Sourcepub fn supports_block_refcounting_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_block_refcounting_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_block_refcounting.
#Errors
If the returned value contains an invalid bit pattern for supports_block_refcounting.
The file system supports sharing logical clusters between files on the same volume. The file system reallocates on writes to shared clusters. Indicates that FSCTL_DUPLICATE_EXTENTS_TO_FILE is a supported operation.
Sourcepub fn with_supports_block_refcounting(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_block_refcounting( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_block_refcounting set to the given value.
#Panics
If the given value is out of bounds for supports_block_refcounting.
The file system supports sharing logical clusters between files on the same volume. The file system reallocates on writes to shared clusters. Indicates that FSCTL_DUPLICATE_EXTENTS_TO_FILE is a supported operation.
Sourcepub fn with_supports_block_refcounting_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_block_refcounting_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_block_refcounting set to the given value.
#Errors
If the given value is out of bounds for supports_block_refcounting.
The file system supports sharing logical clusters between files on the same volume. The file system reallocates on writes to shared clusters. Indicates that FSCTL_DUPLICATE_EXTENTS_TO_FILE is a supported operation.
Sourcepub fn set_supports_block_refcounting(
&mut self,
new_val: <bool as Specifier>::InOut,
)
pub fn set_supports_block_refcounting( &mut self, new_val: <bool as Specifier>::InOut, )
Sets the value of supports_block_refcounting to the given value.
#Panics
If the given value is out of bounds for supports_block_refcounting.
The file system supports sharing logical clusters between files on the same volume. The file system reallocates on writes to shared clusters. Indicates that FSCTL_DUPLICATE_EXTENTS_TO_FILE is a supported operation.
Sourcepub fn set_supports_block_refcounting_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_block_refcounting_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_block_refcounting to the given value.
#Errors
If the given value is out of bounds for supports_block_refcounting.
The file system supports sharing logical clusters between files on the same volume. The file system reallocates on writes to shared clusters. Indicates that FSCTL_DUPLICATE_EXTENTS_TO_FILE is a supported operation.
Sourcepub fn supports_sparse_vdl(&self) -> <bool as Specifier>::InOut
pub fn supports_sparse_vdl(&self) -> <bool as Specifier>::InOut
Returns the value of supports_sparse_vdl. The file system tracks whether each cluster of a file contains valid data (either from explicit file writes or automatic zeros) or invalid data (has not yet been written to or zeroed). File systems that use Sparse VDL do not store a valid data length and do not require that valid data be contiguous within a file.
Sourcepub fn supports_sparse_vdl_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn supports_sparse_vdl_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of supports_sparse_vdl.
#Errors
If the returned value contains an invalid bit pattern for supports_sparse_vdl. The file system tracks whether each cluster of a file contains valid data (either from explicit file writes or automatic zeros) or invalid data (has not yet been written to or zeroed). File systems that use Sparse VDL do not store a valid data length and do not require that valid data be contiguous within a file.
Sourcepub fn with_supports_sparse_vdl(
self,
new_val: <bool as Specifier>::InOut,
) -> Self
pub fn with_supports_sparse_vdl( self, new_val: <bool as Specifier>::InOut, ) -> Self
Returns a copy of the bitfield with the value of supports_sparse_vdl set to the given value.
#Panics
If the given value is out of bounds for supports_sparse_vdl. The file system tracks whether each cluster of a file contains valid data (either from explicit file writes or automatic zeros) or invalid data (has not yet been written to or zeroed). File systems that use Sparse VDL do not store a valid data length and do not require that valid data be contiguous within a file.
Sourcepub fn with_supports_sparse_vdl_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<Self, OutOfBounds>
pub fn with_supports_sparse_vdl_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<Self, OutOfBounds>
Returns a copy of the bitfield with the value of supports_sparse_vdl set to the given value.
#Errors
If the given value is out of bounds for supports_sparse_vdl. The file system tracks whether each cluster of a file contains valid data (either from explicit file writes or automatic zeros) or invalid data (has not yet been written to or zeroed). File systems that use Sparse VDL do not store a valid data length and do not require that valid data be contiguous within a file.
Sourcepub fn set_supports_sparse_vdl(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_supports_sparse_vdl(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of supports_sparse_vdl to the given value.
#Panics
If the given value is out of bounds for supports_sparse_vdl. The file system tracks whether each cluster of a file contains valid data (either from explicit file writes or automatic zeros) or invalid data (has not yet been written to or zeroed). File systems that use Sparse VDL do not store a valid data length and do not require that valid data be contiguous within a file.
Sourcepub fn set_supports_sparse_vdl_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_supports_sparse_vdl_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of supports_sparse_vdl to the given value.
#Errors
If the given value is out of bounds for supports_sparse_vdl. The file system tracks whether each cluster of a file contains valid data (either from explicit file writes or automatic zeros) or invalid data (has not yet been written to or zeroed). File systems that use Sparse VDL do not store a valid data length and do not require that valid data be contiguous within a file.