pub trait FileInfoType:
Sized
+ for<'a> BinRead<Args<'static> = (Self::Class,)>
+ ReadEndian
+ for<'a> BinWrite<Args<'static> = ()>
+ WriteEndian
+ Debug {
type Class;
// Required method
fn class(&self) -> Self::Class;
}Expand description
Trait for file information types. This trait contains all types of all file info types and classes, specified in MS-FSCC.
It’s role is to allow converting an instance of a file information type to a class, and to provide the class type from the file information type.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.